version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "brazrloc/logs/sector-data.log", replace


// CNAE

use "brazaux/auxil/seclvl-cnae", clear
replace year = year + 1900
preserve

* RAIS sector data
tempfile raiscnae
insheet using "rais/base-agg/cnae/aggsec.csv", clear comma
keep clas_cnae_95 ano indprown_pis
rename clas_cnae_95 cnae
drop if cnae<1
replace cnae = int(cnae/10)
rename ano year
keep if year<=1998
label var cnae "Subsector (IBGE)"
label var year "Calendar year"
label var indprown_pis "Share: Jobs at private firms"
replace indprown_pis=. if year<1995
gen _indprown_pis_95 = indprown_pis if year==1995
egen indprown_pis_95 = max(_indprown_pis_95), by(cnae)
drop _indprown_pis_95
label var indprown_pis_95 "Share 95: Jobs at private firms"
sort cnae year
save `raiscnae'
restore

sort cnae year
merge cnae year using `raiscnae'
tab _m  // _m==2: non-manufacturing sectors (agriculture, mining, and all other non-manufacturing sectors)
drop _m
order cnae year secrealx fdiflw fdistk reffpen tarfoutp tarfintm herfsale indprown_pis indprown_pis_95 dollar ppieu ppinam
foreach var in secrealx fdiflw fdistk reffpen tarfoutp tarfintm herfsale indprown_pis indprown_pis_95 dollar ppieu ppinam {
  rename `var' cnae_`var'
  }
sort cnae year
save "brazrloc/auxil/sector-cnae-data", replace


// SUBSECTOR IBGE and DATA MAPPINGS FROM NIVEL 50 TO SUBSECTOR IBGE

* nivel 50 concordance
insheet using "brazrloc/auxil/manual/niv50-subsibge-manual.csv", names comma clear  // compare "brazrloc/auxil/niv50-subsibge-pseudoconc.csv" (from %4tex/compadv-by-secagg.do)
label var subsibge_num "Subsector IBGE"
label var niv50_num "Sector (Nivel 50)"
keep niv50_num subsibge_num
rename niv50_num niv50
rename subsibge_num subs_ibge
count if niv50==niv50[_n-1] | niv50==niv50[_n+1]
if `r(N)'>0  STOP  // concordance incomplete
duplicates tag niv50, gen(_dupl)
count if _dupl>0
if `r(N)'>0  STOP  // not a unique nivel 50 list
drop _dupl

* outside sector data
sort niv50
joinby niv50 using "brazaux/auxil/seclvl", unmatched(both) _merge(_merge)
tab subs_ibge if _m==1  // agriculture
tab niv50 if _m==2  // machinery installation and maintenance
keep if _m==3
sort niv50 year
by niv50: replace herfsale = herfsale[_n-1]/2 + herfsale[_n+1]/2 if year==91  // impute Herfindahl sales index for 1991 as 1990-1992 average
collapse (mean) secrealx fdiflw fdistk reffpen tarfoutp tarfintm herfsale dollar ppieu ppinam ppioecd ppiworld, by(subs_ibge year) fast cw
label var secrealx "Sector real exch. rate (EP*/P)"
label var fdiflw   "FDI Flow (Billion US$)"
label var fdistk   "FDI Stock (Billion US$)"
label var reffpen  "Ramos: Eff. Penetr. of Sector"
label var tarfoutp "Ann. Sectoral Output Tariff"
label var tarfintm "Ann. Sectoral Intm. Input Tariff"
label var herfsale "Herfindahl Index Market Share"
label var dollar   "Nom. Exch.Rate with US$"
label var ppieu    "PPI Idx. EU, import-weight 95"
label var ppinam   "PPI Idx. NAM, import-weight 95"
label var ppioecd  "PPI Idx. OECD, import-weight 95"
label var ppiworld "PPI-WPI-CPI World, imp.-wght 95"
replace year = year + 1900
preserve

* RAIS sector data
tempfile raissubs
insheet using "rais/base-agg/subsibge/aggsec.csv", clear comma
keep subs_ibge ano indprown_pis indunsklb
rename ano year
keep if year<=1998
label var subs_ibge "Subsector (IBGE)"
label var year "Calendar year"
label var indprown_pis "Share: Jobs at private firms"
label var indunsklb "Share: Unskilled blue-coll. occ."
replace indprown_pis=. if year<1995
gen _indprown_pis_95 = indprown_pis if year==1995
egen indprown_pis_95 = max(_indprown_pis_95), by(subs_ibge)
drop _indprown_pis_95
label var indprown_pis_95 "Share 95: Jobs at private firms"
sort subs_ibge year
save `raissubs'
restore

sort subs_ibge year
merge subs_ibge year using `raissubs'
tab _m  // _m==2: non-manufacturing sectors (agriculture, mining, and all other non-manufacturing sectors)
drop _m
order subs_ibge year secrealx fdiflw fdistk reffpen tarfoutp tarfintm herfsale indunsklb indprown_pis indprown_pis_95 dollar ppieu ppinam ppioecd ppiworld
foreach var in secrealx fdiflw fdistk reffpen tarfoutp tarfintm herfsale indunsklb indprown_pis indprown_pis_95 dollar ppieu ppinam ppioecd ppiworld {
  rename `var' subs_`var'
  }
sort subs_ibge year
save "brazrloc/auxil/sector-subsibge-moredata", replace
drop subs_ppioecd subs_ppiworld
save "brazrloc/auxil/sector-subsibge-data", replace

log close
