version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/tex/v4/natl/cohortstats"

capture log close
log using "brazrloc/logs/kim-topel.log", replace


// RAIS: NATIONAL WORKERS, 1-PERCENT SAMPLE //
//------------------------------------------//

* NATIONAL SECTOR TRANSITIONS
*----------------------------

use wid ano identificad sexo mes_deslig rem_media subs_ibge municipio caus_desl_tc fx_etaria grau_instr occagg using "brazrloc/data/wid-draw-workers-natl", clear
rename ano year
sort wid year 
gen byte indfemal = (sexo==2) // female workers
label var indfemal "Indic.: Female worker"
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if year==.

* prepare unaccounted category (post-retirement or death to be excluded, resetting aggsec=9 and tradsec=9 to .)
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid year)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid year rem_media
by wid year: keep if _n==_N
drop rem_media

* potential experience
gen workrage = 12 if fx_etaria==1
replace workrage =   16 if fx_etaria==2
replace workrage =   21 if fx_etaria==3
replace workrage =   27 if fx_etaria==4
replace workrage = 34.5 if fx_etaria==5
replace workrage = 44.5 if fx_etaria==6
replace workrage =   57 if fx_etaria==7
replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
gen potexper     = workrage -  6 if grau_instr==1
replace potexper = workrage -  7 if grau_instr==2
replace potexper = workrage - 10 if grau_instr==3
replace potexper = workrage - 11 if grau_instr==4
replace potexper = workrage - 14 if grau_instr==5
replace potexper = workrage - 15 if grau_instr==6
replace potexper = workrage - 18 if grau_instr==7
replace potexper = workrage - 19 if grau_instr==8
replace potexper = workrage - 22 if grau_instr==9
label var potexper "Potential labor force experience"
gen byte indyoung = (potexper<10)   // if potexper < 10
label var indyoung "Indic.: Pot. labf. exp. < 10yrs."
drop workrage

* entrant indicator
egen _firstyr = min(year), by(wid)
gen byte indentr = (_firstyr>=1990 & indyoung==1)
label var indentr "Indic.: Labf. entrant"
drop _firstyr

* education indicator
gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
drop grau_instr

* occupation indicator (based on 3-digit cbo; see rais/cbo/cbogrp2occagg.csv)
gen byte indwhpls = (occagg==1 | occagg==2 | occagg==3)   // if indprof | indtech | indwhit (indwhit+)
label var indwhpls "Indic.: White Collar Occupation"
drop occagg

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge cnae 1995 sector and comparative advantage information (for 1986-98)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98", nokeep
tab _m  // _m==1: years 1999-2001 (but mod_clas_cnae_95==. also for _m==3 when firm not recorded in 1995)
count if mod==. & _m==3
drop _m indcnts13
rename ano year
rename mod_clas_cnae_95 cnae
sort cnae year
merge cnae year using "brazaux/intl/balassa-compadv-cnae", nokeep
rename cnae mod_clas_cnae_95
tab _m  // _m==1: nontraded sectors and years 1999-2001
tab subs_ibge if _m==1 & year<=1998
tab year if _m==1
drop wrld_exp wrld_tot braz_exp braz_tot balcadv
gen byte cnaesec = 7 if _m==1 & year<=1998 & mod_clas_cnae_95~=.  // no Balassa traded good sector merge, but also not missing 1995 sector information
forvalues i=1/5 {
  replace cnaesec = `i' if balarank==`i'
  }
label var cnaesec "CNAE/Balassa Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values cnaesec tradsec
drop _m balarank mod_clas_cnae_95

* merge aggregate sector and Balassa comparative advantage information
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balcadv
rename subsibge subs_ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector information
drop _m
qui do "brazrloc/auxil/aggsec.do"
label values aggsec aggsec
gen byte tradsec = 7 if aggsec>3
forvalues i=1/5 {
  replace tradsec = `i' if balarank==`i'
  }
label var tradsec "Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values tradsec tradsec
drop balarank

* merge aggregate sector and Vollrath comparative advantage information
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge", nokeep keep(volrrank)
tab _m  // _m==1: workers in nontraded goods sectors
drop _m
rename subsibge subs_ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector information
drop _m
qui do "brazrloc/auxil/aggsec.do"
label values aggsec aggsec
gen byte vollrsec = 7 if aggsec>3
forvalues i=1/5 {
  replace vollrsec = `i' if volrrank==`i'
  }
label var vollrsec "Trade Sectors (Vollrath 1992)
qui do "brazrloc/auxil/tradsec.do"
label values vollrsec tradsec
drop volrrank

* redefine aggsec to merge agriculture and mining into primary
replace aggsec = 0 if aggsec==1 | aggsec==2

* merge export status information by firm
sort cnpj_radic year
rename year ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid year
replace aggsec = 9 if _fillin
replace tradsec = 9 if _fillin
replace vollrsec = 9 if _fillin
replace cnaesec = 9 if _fillin & year<=1998
sort wid year
by wid: replace rm = rm[_n-1] if _fillin
drop _fillin

* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
sort wid year
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 | fx_etaria[_n-8]==8 | fx_etaria[_n-9]==8 | fx_etaria[_n-10]==8 | fx_etaria[_n-11]==8 | fx_etaria[_n-12]==8 | fx_etaria[_n-13]==8 | fx_etaria[_n-14]==8 | fx_etaria[_n-15]==8 | fx_etaria[_n-16]==8 ) ) )
drop fx_etaria
replace aggsec = . if indretired
replace tradsec = . if indretired
replace vollrsec = . if indretired
drop indretired _retiryr _deathyr

* finalize
sort wid year subs_ibge
tsset wid year


* KIM-TOPEL (1995) TABULATION FOR 1986, 1990, 1994, 1998

keep if year==1986 | year==1990 | year==1994 | year==1998
sort wid year
tsset wid year
* kim-topel indicators
gen byte indkt = (potexper<4)   // if potexper < 4
label var indkt "Indic.: Kim-Topel (1995) entrant"

foreach year in 1986 1990 1994 1998 {
  local yr = substr("`year'",3,2)
  gen byte indkt`yr' = (indkt & year==`year')
  label var indkt`yr' "Indic.: Kim-Topel entrant in `year'"
  replace indkt`yr'=. if year~=`year'
  egen byte _indkt`yr' = max(indkt`yr'), by(wid)
  replace indkt`yr' = _indkt`yr' if indkt`yr'==.
  drop _indkt`yr'
  }

* 1986
tab tradsec if indkt86 & year==1986 & tradsec~=9, matcell(yng_coh86yr1986)
mat yng_coh86yr1986_tot = J(1,6,1) * yng_coh86yr1986
mat yng_coh86yr1986 = yng_coh86yr1986 / yng_coh86yr1986_tot[1,1]
mat rownames yng_coh86yr1986 = yng_coh86:1 yng_coh86:2 yng_coh86:3 yng_coh86:4 yng_coh86:5 yng_coh86:7
tab tradsec if !indkt86 & year==1986 & tradsec~=9, matcell(old_coh86yr1986)
mat old_coh86yr1986_tot = J(1,6,1) * old_coh86yr1986
mat old_coh86yr1986 = old_coh86yr1986 / old_coh86yr1986_tot[1,1]
mat rownames old_coh86yr1986 = old_coh86:1 old_coh86:2 old_coh86:3 old_coh86:4 old_coh86:5 old_coh86:7
mat yngold_tradsec_1986 = yng_coh86yr1986 \ old_coh86yr1986
mat colnames yngold_tradsec_1986 = yr1986
mat kt_tradsec_1986 = yng_coh86yr1986 \ old_coh86yr1986
mat colnames kt_tradsec_1986 = yr1986
mat drop yng_coh86yr1986 old_coh86yr1986 yng_coh86yr1986_tot old_coh86yr1986_tot

* 1990
tab tradsec if indkt90 & year==1990 & tradsec~=9, matcell(yng_coh90yr1990)
mat yng_coh90yr1990_tot = J(1,6,1) * yng_coh90yr1990
mat yng_coh90yr1990 = yng_coh90yr1990 / yng_coh90yr1990_tot[1,1]
mat rownames yng_coh90yr1990 = yng_coh90:1 yng_coh90:2 yng_coh90:3 yng_coh90:4 yng_coh90:5 yng_coh90:7
tab tradsec if !indkt90 & year==1990 & tradsec~=9, matcell(old_coh90yr1990)
mat old_coh90yr1990_tot = J(1,6,1) * old_coh90yr1990
mat old_coh90yr1990 = old_coh90yr1990 / old_coh90yr1990_tot[1,1]
mat rownames old_coh90yr1990 = old_coh90:1 old_coh90:2 old_coh90:3 old_coh90:4 old_coh90:5 old_coh90:7
tab tradsec if indkt86 & year==1990 & tradsec~=9, matcell(mid_coh86yr1990)
mat mid_coh86yr1990_tot = J(1,6,1) * mid_coh86yr1990
mat mid_coh86yr1990 = mid_coh86yr1990 / mid_coh86yr1990_tot[1,1]
mat rownames mid_coh86yr1990 = mid_coh86:1 mid_coh86:2 mid_coh86:3 mid_coh86:4 mid_coh86:5 mid_coh86:7
tab tradsec if !indkt86 & !indkt90 & year==1990 & tradsec~=9, matcell(old_coh86yr1990)
mat old_coh86yr1990_tot = J(1,6,1) * old_coh86yr1990
mat old_coh86yr1990 = old_coh86yr1990 / old_coh86yr1990_tot[1,1]
mat rownames old_coh86yr1990 = old_coh86:1 old_coh86:2 old_coh86:3 old_coh86:4 old_coh86:5 old_coh86:7
mat yngold_tradsec_1990 = yng_coh90yr1990 \ old_coh90yr1990
mat colnames yngold_tradsec_1990 = yr1990
mat kt_tradsec_1990 = yng_coh90yr1990 \ mid_coh86yr1990 \ old_coh86yr1990
mat colnames kt_tradsec_1990 = yr1990
mat drop yng_coh90yr1990 old_coh90yr1990 mid_coh86yr1990 old_coh86yr1990 yng_coh90yr1990_tot old_coh90yr1990_tot mid_coh86yr1990_tot old_coh86yr1990_tot

* 1994
tab tradsec if indkt94 & year==1994 & tradsec~=9, matcell(yng_coh94yr1994)
mat yng_coh94yr1994_tot = J(1,6,1) * yng_coh94yr1994
mat yng_coh94yr1994 = yng_coh94yr1994 / yng_coh94yr1994_tot[1,1]
mat rownames yng_coh94yr1994 = yng_coh94:1 yng_coh94:2 yng_coh94:3 yng_coh94:4 yng_coh94:5 yng_coh94:7
tab tradsec if !indkt94 & year==1994 & tradsec~=9, matcell(old_coh94yr1994)
mat old_coh94yr1994_tot = J(1,6,1) * old_coh94yr1994
mat old_coh94yr1994 = old_coh94yr1994 / old_coh94yr1994_tot[1,1]
mat rownames old_coh94yr1994 = old_coh94:1 old_coh94:2 old_coh94:3 old_coh94:4 old_coh94:5 old_coh94:7
tab tradsec if indkt86 & year==1994 & tradsec~=9, matcell(mid_coh86yr1994)
mat mid_coh86yr1994_tot = J(1,6,1) * mid_coh86yr1994
mat mid_coh86yr1994 = mid_coh86yr1994 / mid_coh86yr1994_tot[1,1]
mat rownames mid_coh86yr1994 = mid_coh86:1 mid_coh86:2 mid_coh86:3 mid_coh86:4 mid_coh86:5 mid_coh86:7
tab tradsec if indkt90 & year==1994 & tradsec~=9, matcell(mid_coh90yr1994)
mat mid_coh90yr1994_tot = J(1,6,1) * mid_coh90yr1994
mat mid_coh90yr1994 = mid_coh90yr1994 / mid_coh90yr1994_tot[1,1]
mat rownames mid_coh90yr1994 = mid_coh90:1 mid_coh90:2 mid_coh90:3 mid_coh90:4 mid_coh90:5 mid_coh90:7
tab tradsec if !indkt86 & !indkt90 & !indkt94 & year==1994 & tradsec~=9, matcell(old_coh86yr1994)
mat old_coh86yr1994_tot = J(1,6,1) * old_coh86yr1994
mat old_coh86yr1994 = old_coh86yr1994 / old_coh86yr1994_tot[1,1]
mat rownames old_coh86yr1994 = old_coh86:1 old_coh86:2 old_coh86:3 old_coh86:4 old_coh86:5 old_coh86:7
mat yngold_tradsec_1994 = yng_coh94yr1994 \ old_coh94yr1994
mat colnames yngold_tradsec_1994 = yr1994
mat kt_tradsec_1994 = yng_coh94yr1994 \ mid_coh90yr1994 \ mid_coh86yr1994 \ old_coh86yr1994
mat colnames kt_tradsec_1994 = yr1994
mat drop yng_coh94yr1994 old_coh94yr1994 mid_coh86yr1994 mid_coh90yr1994 old_coh86yr1994 yng_coh94yr1994_tot old_coh94yr1994_tot mid_coh86yr1994_tot mid_coh90yr1994_tot old_coh86yr1994_tot

* 1998
tab tradsec if indkt98 & year==1998 & tradsec~=9, matcell(yng_coh98yr1998)
mat yng_coh98yr1998_tot = J(1,6,1) * yng_coh98yr1998
mat yng_coh98yr1998 = yng_coh98yr1998 / yng_coh98yr1998_tot[1,1]
mat rownames yng_coh98yr1998 = yng_coh98:1 yng_coh98:2 yng_coh98:3 yng_coh98:4 yng_coh98:5 yng_coh98:7
tab tradsec if !indkt98 & year==1998 & tradsec~=9, matcell(old_coh98yr1998)
mat old_coh98yr1998_tot = J(1,6,1) * old_coh98yr1998
mat old_coh98yr1998 = old_coh98yr1998 / old_coh98yr1998_tot[1,1]
mat rownames old_coh98yr1998 = old_coh98:1 old_coh98:2 old_coh98:3 old_coh98:4 old_coh98:5 old_coh98:7
tab tradsec if indkt86 & year==1998 & tradsec~=9, matcell(mid_coh86yr1998)
mat mid_coh86yr1998_tot = J(1,6,1) * mid_coh86yr1998
mat mid_coh86yr1998 = mid_coh86yr1998 / mid_coh86yr1998_tot[1,1]
mat rownames mid_coh86yr1998 = mid_coh86:1 mid_coh86:2 mid_coh86:3 mid_coh86:4 mid_coh86:5 mid_coh86:7
tab tradsec if indkt90 & year==1998 & tradsec~=9, matcell(mid_coh90yr1998)
mat mid_coh90yr1998_tot = J(1,6,1) * mid_coh90yr1998
mat mid_coh90yr1998 = mid_coh90yr1998 / mid_coh90yr1998_tot[1,1]
mat rownames mid_coh90yr1998 = mid_coh90:1 mid_coh90:2 mid_coh90:3 mid_coh90:4 mid_coh90:5 mid_coh90:7
tab tradsec if indkt94 & year==1998 & tradsec~=9, matcell(mid_coh94yr1998)
mat mid_coh94yr1998_tot = J(1,6,1) * mid_coh94yr1998
mat mid_coh94yr1998 = mid_coh94yr1998 / mid_coh94yr1998_tot[1,1]
mat rownames mid_coh94yr1998 = mid_coh94:1 mid_coh94:2 mid_coh94:3 mid_coh94:4 mid_coh94:5 mid_coh94:7
tab tradsec if !indkt86 & !indkt90 & !indkt98 & year==1998 & tradsec~=9, matcell(old_coh86yr1998)
mat old_coh86yr1998_tot = J(1,6,1) * old_coh86yr1998
mat old_coh86yr1998 = old_coh86yr1998 / old_coh86yr1998_tot[1,1]
mat rownames old_coh86yr1998 = old_coh86:1 old_coh86:2 old_coh86:3 old_coh86:4 old_coh86:5 old_coh86:7
mat yngold_tradsec_1998 = yng_coh98yr1998 \ old_coh98yr1998
mat colnames yngold_tradsec_1998 = yr1998
mat kt_tradsec_1998 = yng_coh98yr1998 \ mid_coh94yr1998 \ mid_coh90yr1998 \ mid_coh86yr1998 \ old_coh86yr1998
mat colnames kt_tradsec_1998 = yr1998
mat drop yng_coh98yr1998 old_coh98yr1998 mid_coh86yr1998 mid_coh90yr1998 mid_coh94yr1998 old_coh86yr1998 yng_coh98yr1998_tot old_coh98yr1998_tot mid_coh86yr1998_tot mid_coh90yr1998_tot mid_coh94yr1998_tot old_coh86yr1998_tot

mat rename kt_tradsec_1998 kt_tradsec_tbl
foreach year in 1994 1990 1986 {
  local donecols = colsof(kt_tradsec_tbl)
  local newcol = `donecols' + 1
  local colname : colnames kt_tradsec_`year'
  mat kt_tradsec_tbl = kt_tradsec_tbl , ( J(`donecols'*6,1,.) \ kt_tradsec_`year' )
  matname kt_tradsec_tbl `colname', columns(`newcol') explicit
  }
matorder kt_tradsec_tbl, m(kt_tradsec_tbl) over ifc(yr1986 yr1990 yr1994 yr1998)
mat rename yngold_tradsec_1986 yngold_tradsec_tbl
foreach year in 1990 1994 1998 {
  local donecols = colsof(yngold_tradsec_tbl)
  local yr = substr("`year'",3,2)
  mat _matadd = J(6,`donecols',.)
  mat rownames _matadd = yng_coh`yr':1 yng_coh`yr':2 yng_coh`yr':3 yng_coh`yr':4 yng_coh`yr':5 yng_coh`yr':7
  mat yngold_tradsec_tbl = ( _matadd \ yngold_tradsec_tbl ) , (  yngold_tradsec_`year' \ J(`donecols'*6,1,.) )
  }
mat colnames yngold_tradsec_tbl = yr1986 yr1990 yr1994 yr1998

est2tex yngold_tradsec, p(brazrloc/tex/v4/natl/cohortstats) ready dropall fancy digits(3) replace
est2tex kt_tradsec, p(brazrloc/tex/v4/natl/cohortstats) ready dropall fancy digits(3) replace

log close
