version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/accessions-natl-subsibge.log", replace

local maxiter $maxiter

local focallst "subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf"
local addlst   "subs_balcadv_indexp subs_balcadv_indexp_tarf"
local cntrlfrm "subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local cntrlwrk "indprof indtech indwhit indsklb indfemal"
local addlwrkr "indhigh indscoll indgrad" 
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"

* SUBSECTOR IBGE VARIABLES, BRAZILIAN PRIME-AGE MALES
*----------------------------------------------------

capture confirm file "brazrloc/data/accessions-natl-subsibge.dta"
if _rc ~= 0 {
use wid ano sexo identificad mes_adm rem_media subs_ibge tipo_adm fx_etaria grau_instr cbogrp occagg if ano<=1998 using "brazrloc/data/wid-draw-workers-natl", clear
gen byte indfemal = (sexo==2) // female workers
label var indfemal "Indic.: Female worker"
drop sexo
rename ano year
sort wid year 

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if year==.

* identify accession (excluding transfer)
gen byte indhire = (mes_adm > 0 & tipo_adm~=0 & tipo_adm~=3 & tipo_adm~=4)
label var indhire "Indic.: Accession"
drop tipo_adm

* keep first employment per year
egen byte _firstjob = min(mes_adm), by(wid year)
gen byte indexcl = (mes_adm~=_firstjob)
label var indexcl "Indic.: Not first job in year"
drop _firstjob

* keep employment with highest pay if more than one first employment per year (random drop for pay ties)
sort wid year indexcl rem_media
by wid year indexcl: replace indexcl=1 if _n~=_N

// SECTOR VARIABLES, MAPPING WITH SUBS_IBGE

* merge aggregate sector and comparative advantage information
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balarank
rename subsibge subs_ibge
rename balcadv subs_balcadv

* merge additional sector information
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb

* reset private-job share before 1995 to 1995
replace subs_indprown_pis = subs_indprown_pis_95 if subs_indprown_pis==.
drop subs_indprown_pis_95

// OCCUPATION VARIABLES

* outsourceable job share
sort cbogrp
merge cbogrp using "brazaux/auxil/cbogrp-outsourcing", nokeep
tab _m  // _m==1: CBO group missing
count if _m~=3 & cbogrp~=.
if `r(N)'>0  STOP  // incomplete CBO mapping
rename indoutsrc occ_indoutsrc
drop _m cbogrp

// PLANT VARIABLES

* merge RAIS information by plant
rename year ano
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-data-natl", nokeep
tab _m  // _m==1: single worker firms will be omitted from regression with plant-level variables
drop _m
replace plant_n_pis = ln(plant_n_pis)
rename plant_n_pis plant_lnempl
label var plant_lnempl "Log Employment"

// FIRM VARIABLES

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge export status information by firm
sort cnpj_radic ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year
rename indexp firm_indexp

* merge PIA information
rename cnpj_radic firm
sort firm year
merge firm year using "brazrloc/data/pia-data"
tab _m
drop if _m==2
drop firm_lntfp firm_ln_cap_empl _m
iis, clear
tis, clear
tsset, clear
rename firm cnpj_radic

// WORKER VARIABLES

* potential experience
gen workrage = 12 if fx_etaria==1
replace workrage =   16 if fx_etaria==2
replace workrage =   21 if fx_etaria==3
replace workrage =   27 if fx_etaria==4
replace workrage = 34.5 if fx_etaria==5
replace workrage = 44.5 if fx_etaria==6
replace workrage =   57 if fx_etaria==7
replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
gen potexper     = workrage -  6 if grau_instr==1
replace potexper = workrage -  7 if grau_instr==2
replace potexper = workrage - 10 if grau_instr==3
replace potexper = workrage - 11 if grau_instr==4
replace potexper = workrage - 14 if grau_instr==5
replace potexper = workrage - 15 if grau_instr==6
replace potexper = workrage - 18 if grau_instr==7
replace potexper = workrage - 19 if grau_instr==8
replace potexper = workrage - 22 if grau_instr==9
label var potexper "Potential labor force experience"
drop workrage fx_etaria

* education indicators
gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
gen byte indscoll = (grau_instr==8)
label var indscoll "Some College Education"
gen byte indgrad = (grau_instr==9)
label var indgrad "Complete College Education"
drop grau_instr

* occupation indicators (based on 3-digit cbo; see rais/cbo/cbogrp2occagg.csv)
gen byte indprof = (occagg==1)
label var indprof "Professional or Managerial Occ."
gen byte indtech = (occagg==2)
label var indtech "Technical or Supervisory Occup."
gen byte indwhit = (occagg==3)
label var indwhit "Other White Collar Occupation"
gen byte indsklb = (occagg==4)
label var indsklb "Skilled Blue Collar Occupation"
gen byte indunsklb = (occagg==5)
label var indunsklb "Unskilled Blue Collar Occupation"
drop occagg

// ANNUAL VARIABLES

* exporting status instruments
sort year
merge year using "brazrloc/auxil/wtf-data", nokeep
count if _m~=3
if `r(N)' > 0  STOP  // years incomplete in wtf-data.dta
drop _m

// FINALIZE ESTIMATION SAMPLE

sort wid year mes_adm rem_media cnpj_radic
drop mes_adm rem_media

* interaction variables and dummies
gen subs_balcadv_tarf = subs_balcadv * subs_tarfoutp
label var subs_balcadv_tarf "subs_balcadv * subs_tarfoutp"
gen firm_indexp_tarf = firm_indexp * subs_tarfoutp
label var firm_indexp_tarf "firm_indexp * subs_tarfoutp"
gen subs_balcadv_indexp = subs_balcadv * firm_indexp
label var subs_balcadv_indexp "subs_balcadv * firm_indexp"
gen subs_balcadv_indexp_tarf = subs_balcadv * subs_tarfoutp * firm_indexp
label var subs_balcadv_indexp_tarf "subs_balcad * _tarfout * _indexp"
qui tab year, generate(indyr_)
qui tab subs_ibge, generate(indsubs_) nolab
drop subs_ibge

order wid year cnpj_radic indhire indexcl subs_balcadv* subs_fdiflw subs_reffpen subs_tarfoutp subs_tarfintm subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_indexp* firm_lnlp potexper indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb indfemal subs_dollar subs_ppieu subs_ppinam
save "brazrloc/data/accessions-natl-subsibge.dta", replace
}

else use "brazrloc/data/accessions-natl-subsibge.dta", clear

// keep only first accession per year
drop if indexcl


* IV REGRESSIONS: FIRST STAGE

local rnd 0
foreach depvar in `endog' {
  local rnd = `rnd' + 1
  reg `depvar' subs_balcadv `baseiv' `cntrlfrm' `cntrlwrk'
  * xtreg `depvar' subs_balcadv `baseiv' `cntrlfrm' `cntrlwrk', fe i(cnpj_radic)
  if `rnd'==1  est2vec subs_hire_iv1st, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp indprof indtech indwhit indsklb indunsklb indfemal indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) name(`depvar')
  else         est2vec subs_hire_iv1st, addto(subs_hire_iv1st) name(`depvar')
  test `baseiv'
  if `rnd'==1  est2vec subs_hire_iv1st, r(F p df df_r) name(`depvar')
  else         est2vec subs_hire_iv1st, raddto(subs_hire_iv1st) name(`depvar')
  predict prd_`depvar', xb
  label var prd_`depvar' "OLS prediction: `depvar'"
  predict res_`depvar', residuals
  label var res_`depvar' "OLS residuals: `depvar'"
  }
reg firm_indexp subs_balcadv `expiv' `cntrlfrm'
* xtreg firm_indexp subs_balcadv `expiv' `cntrlfrm', fe i(cnpj_radic)
est2vec subs_hire_iv1st, addto(subs_hire_iv1st) name(firm_indexp)
test `expiv'
est2vec subs_hire_iv1st, raddto(subs_hire_iv1st) name(firm_indexp)
predict prd_indexp, xb
label var prd_indexp "OLS prediction: indexp"
predict res_indexp, residuals
label var res_indexp "OLS residuals: indexp"
preserve
  keep cnpj_radic year firm_indexp `focallst' `expiv' `cntrlfrm'
  sort cnpj_radic year
  by cnpj_radic year: keep if _n==1
  reg firm_indexp subs_balcadv `expiv' `cntrlfrm'
  * xtreg firm_indexp subs_balcadv `expiv' `cntrlfrm', fe i(cnpj_radic)
  est2vec subs_hire_iv1st, addto(subs_hire_iv1st) name(firm_indexp_frmlvl)
  test `expiv'
  est2vec subs_hire_iv1st, raddto(subs_hire_iv1st) name(firm_indexp_frmlvl)
  reg firm_indexp subs_balcadv subs_balcadv_tarf `expiv' `cntrlfrm'
  * xtreg firm_indexp subs_balcadv subs_balcadv_tarf `expiv' `cntrlfrm', fe i(cnpj_radic)
  est2vec subs_hire_iv1st, addto(subs_hire_iv1st) name(firm_indexp_frmlvl_all)
  test `expiv'
  est2vec subs_hire_iv1st, raddto(subs_hire_iv1st) name(firm_indexp_frmlvl_all)
restore
drop cnpj_radic


* REGRESSIONS

// main regression

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp indprof indtech indwhit indsklb indunsklb indfemal indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_focal)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

clogit indhire `focallst' `addlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_all)

// comparisons with omitted focal variables

clogit indhire subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_nointrct)

clogit indhire subs_balcadv `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_balcadv)

clogit indhire subs_balcadv subs_balcadv_tarf `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_balcadv_tarf)

clogit indhire firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_indexp)

clogit indhire firm_indexp firm_indexp_tarf subs_tarfoutp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_indexp_tarf)

clogit indhire subs_tarfoutp subs_tarfintm `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_aspme)

// xt comparison regressions

xtreg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indsmpl, fe i(wid)
est2vec subs_hire, addto(subs_hire) name(xtreg_ifclogit)

xtreg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid)
est2vec subs_hire, addto(subs_hire) name(xtreg)

xtreg indhire subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid)
est2vec subs_hire, addto(subs_hire) name(xtreg_nointrct)

// logit comparison regressions

logit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indsmpl, robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(logit_focal_ifclogit)

logit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(logit_focal)

logit indhire `focallst' `endog' `addlst' `cntrlfrm' `cntrlwrk' indyr* if indsmpl, robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(logit_all_ifclogit)

logit indhire `focallst' `endog' `addlst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(logit_all)

logit indhire subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(logit_focal_nointrct)

// ols comparison regressions

reg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indsmpl, cluster(wid)
est2vec subs_hire, addto(subs_hire) name(ols_ifclogit)

reg indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, cluster(wid)
est2vec subs_hire, addto(subs_hire) name(ols)

reg indhire subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, cluster(wid)
est2vec subs_hire, addto(subs_hire) name(ols_nointrct)

// robustness checks

clogit indhire subs_balcadv subs_balcadv_tarf `endog' `cntrlfrm' `cntrlwrk' indyr*, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_allyrs)

clogit indhire `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_nofocal)

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_indsubs)

clogit indhire `focallst' subs_indprown_pis `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_indprown)

clogit indhire `focallst' occ_indoutsrc `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_indoutsrc)

clogit indhire `focallst' firm_lnlp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_lnlp)

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' `addlwrkr' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_addlwrkr)

// iv

clogit indhire subs_balcadv firm_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_iv_tarfetc)

clogit indhire subs_balcadv prd_indexp res_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_iv_indexp)

clogit indhire subs_balcadv prd_indexp res_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_iv_all)

xtivreg indhire subs_balcadv subs_balcadv_tarf `cntrlfrm' `cntrlwrk' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe i(wid)
est2vec subs_hire, addto(subs_hire) name(xtivreg)

xtivreg indhire subs_balcadv `cntrlfrm' `cntrlwrk' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe i(wid)
est2vec subs_hire, addto(subs_hire) name(xtivreg_nointrct)

ivreg indhire subs_balcadv subs_balcadv_tarf `cntrlfrm' `cntrlwrk' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, cluster(wid)
est2vec subs_hire, addto(subs_hire) name(olsiv)

ivreg indhire subs_balcadv `cntrlfrm' `cntrlwrk' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, cluster(wid)
est2vec subs_hire, addto(subs_hire) name(olsiv_nointrct)

// education group subsamples

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indprim & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_indprim)

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indhigh & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_indhigh)

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indscoll | indgrad & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subs_hire, addto(subs_hire) name(clogit_indcoll)

// alternative accession definitions

* clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indexcl & year>=1990, group(wid) robust iterate(`maxiter')
* est2vec subs_hire, addto(subs_hire) name(clogit_firstjobs)  // sample of first jobs per year


* SAVE RESULTS

preserve
foreach type in b se e {
  matsave subs_hire_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }
foreach type in b se e r {
  matsave subs_hire_iv1st_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }
restore
drop prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp indsmpl

log close

