version 8
set more off
set virtual on
clear
set trace off

cd "$root"

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"
capture mkdir "brazrloc/graphs/v4/natl"
capture mkdir "brazrloc/graphs/v4/natl/hazard"

capture log close
log using "brazrloc/logs/hazard-durations-natl-subsibge.log", replace

local maxiter $maxiter

local rehirlst "subs_balcadv_rehir firm_indexp_rehir"
local rehrendg "subs_tarfoutp_rehir subs_tarfintm_rehir subs_reffpen_rehir"
local focallst "subs_balcadv firm_indexp"
local addlst   "subs_balcadv_tarf firm_indexp_tarf"
local morelst  "subs_balcadv_indexp subs_balcadv_indexp_tarf"  // currently unused
local cntrlfrm "subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb indfemal"
local addlwrkr "indhigh indscoll indgrad" 
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"

* DURATIONS OF SUCCESSFUL REALLOCATIONS

capture confirm file "brazrloc/data/hazard-durations-natl-subsibge.dta"
if _rc ~= 0 {
use wid ano mes_adm mes_deslig identificad caus_desl_tc fx_etaria sexo rem_media subs_ibge cbogrp temp_empr grau_instr occagg using "brazrloc/data/wid-draw-workers-natl", clear
gen byte indfemal = (sexo==2) // female workers
label var indfemal "Indic.: Female worker"
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
sort wid ano mes_adm mes_deslig identificad

* identify displacement and month of first rehiring
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
by wid: gen str7 morehir = string(mes_adm[_n+1]) + "/" + string(ano[_n+1]) if inddspl==1
by wid: gen double cnpj_radic_rehir = int(identificad[_n+1]/1000000) if inddspl==1
by wid: gen byte subs_ibge_rehir = subs_ibge[_n+1] if inddspl==1
by wid: gen int ano_rehir = ano[_n+1] if inddspl==1
label var inddspl "Indic.: Displacement"
label var morehir "Month of first rehiring"
label var cnpj_radic_rehir "Firm of first rehiring (ID)"
label var subs_ibge_rehir "Sector of first rehiring"
label var ano_rehir "Year of first rehiring"
drop caus_desl_tc

* discard rehirings if plant missing in year before rehiring
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-list-natl"
tab _m
keep if _m==3
keep wid ano* mes_adm mes_deslig identificad cnpj_radic_rehir inddspl morehir indabsyr1 rem_media subs_ibge* cbogrp temp_empr fx_etaria grau_instr occagg indfemal
sort wid ano mes_adm mes_deslig identificad
by wid: gen byte inddisc = indabsyr1[_n+1]
label var inddisc "Plant missing year bef. realloc."
drop indabsyr1

* calculate months from displacement to first rehiring
gen int mo2rehir = (int(real(substr(morehir,-4,4))) - ano)*12 + (int(real(substr(morehir,1,index(morehir,"/")-1))) - mes_desl)
replace mo2rehir = 0 if int(real(substr(morehir,-4,4)))==ano & int(real(substr(morehir,1,index(morehir,"/")-1)))<mes_desl
label var mo2rehir "Months to re-employment"

* keep last employment per year
rename ano year
rename ano_rehir year_rehir
egen byte _lastjob = max(mes_deslig), by(wid year)
gen byte indexcl = (mes_deslig~=_lastjob)
label var indexcl "Indic.: Not last job in year"
drop _lastjob

* keep employment with highest pay if more than one last employment per year (random drop for pay ties)
sort wid year indexcl rem_media
by wid year indexcl: replace indexcl=1 if _n~=_N

* drop 1999-2001 and unused variables
drop if year>1998
drop morehir
order wid year mo2rehir

// DISPLACING AND REHIRING SECTOR VARIABLES, MAPPING WITH SUBS_IBGE

rename subs_ibge _subs_ibge
rename subs_ibge_rehir _subs_ibge_rehir
foreach time in "_rehir" "" {

* merge aggregate sector and comparative advantage information
rename _subs_ibge`time' subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balarank
rename subsibge _subs_ibge`time'
rename balcadv subs_balcadv`time'

* merge additional sector information
rename _subs_ibge`time' subs_ibge
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
if "`time'"==""        count if _m~=3
if "`time'"=="_rehir"  count if _m~=3 & mo2rehir~=.
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb
foreach var in subs_fdiflw subs_secrealx subs_reffpen subs_tarfoutp subs_tarfintm subs_herfsale subs_indprown_pis subs_indprown_pis_95 subs_dollar subs_ppieu subs_ppinam {
  if "`time'"~=""  rename `var' `var'`time'
  }
rename subs_ibge _subs_ibge`time'

* reset private-job share before 1995 to 1995
replace subs_indprown_pis`time' = subs_indprown_pis_95`time' if subs_indprown_pis`time'==.
drop subs_indprown_pis_95

} /* close `time' loop for sector variables */
rename _subs_ibge subs_ibge
rename _subs_ibge_rehir subs_ibge_rehir

// OCCUPATION VARIABLES

* outsourceable job share
sort cbogrp
merge cbogrp using "brazaux/auxil/cbogrp-outsourcing", nokeep
tab _m  // _m==1: CBO group missing
count if _m~=3 & cbogrp~=.
if `r(N)'>0  STOP  // incomplete CBO mapping
rename indoutsrc occ_indoutsrc
drop _m cbogrp

// PLANT VARIABLES

* merge RAIS information by plant
rename year ano
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-data-natl", nokeep
tab _m  // _m==1: single worker firms will be omitted from regression with plant-level variables
drop _m
replace plant_n_pis = ln(plant_n_pis)
rename plant_n_pis plant_lnempl
label var plant_lnempl "Log Employment"
rename ano year

// FIRM VARIABLES

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

rename cnpj_radic _cnpj_radic
rename cnpj_radic_rehir _cnpj_radic_rehir
foreach time in "_rehir" "" {

* merge export status information by firm
rename year ano
rename _cnpj_radic`time' cnpj_radic
sort cnpj_radic ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year
rename indexp firm_indexp`time'

* merge PIA information
rename cnpj_radic firm
sort firm year
merge firm year using "brazrloc/data/pia-data"
tab _m
drop if _m==2
drop firm_lntfp firm_ln_cap_empl _m
iis, clear
tis, clear
tsset, clear
if "`time'"~=""  rename firm_lnlp firm_lnlp`time'
rename firm _cnpj_radic`time'

} /* close `time' loop for firm variables */
rename _cnpj_radic cnpj_radic
rename _cnpj_radic_rehir cnpj_radic_rehir


// WORKER VARIABLES

* tenure
replace temp_empr = temp_empr/52
rename temp_empr tenuryr
label var tenuryr "Tenure at plant (in years)"
gen tenr2 = tenuryr*tenuryr
label var tenr2 "Quadratic Tenure Term"

* potential experience
gen workrage = 12 if fx_etaria==1
replace workrage =   16 if fx_etaria==2
replace workrage =   21 if fx_etaria==3
replace workrage =   27 if fx_etaria==4
replace workrage = 34.5 if fx_etaria==5
replace workrage = 44.5 if fx_etaria==6
replace workrage =   57 if fx_etaria==7
replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
gen potexper     = workrage -  6 if grau_instr==1
replace potexper = workrage -  7 if grau_instr==2
replace potexper = workrage - 10 if grau_instr==3
replace potexper = workrage - 11 if grau_instr==4
replace potexper = workrage - 14 if grau_instr==5
replace potexper = workrage - 15 if grau_instr==6
replace potexper = workrage - 18 if grau_instr==7
replace potexper = workrage - 19 if grau_instr==8
replace potexper = workrage - 22 if grau_instr==9
label var potexper "Potential labor force experience"
drop workrage fx_etaria
gen potxper2 = potexper*potexper
label var potxper2 "Quadratic Experience Term"

* education indicators
gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
gen byte indscoll = (grau_instr==8)
label var indscoll "Some College Education"
gen byte indgrad = (grau_instr==9)
label var indgrad "Complete College Education"
drop grau_instr

* occupation indicators (based on 3-digit cbo; see rais/cbo/cbogrp2occagg.csv)
gen byte indprof = (occagg==1)
label var indprof "Professional or Managerial Occ."
gen byte indtech = (occagg==2)
label var indtech "Technical or Supervisory Occup."
gen byte indwhit = (occagg==3)
label var indwhit "Other White Collar Occupation"
gen byte indsklb = (occagg==4)
label var indsklb "Skilled Blue Collar Occupation"
gen byte indunsklb = (occagg==5)
label var indunsklb "Unskilled Blue Collar Occupation"
drop occagg

// ANNUAL VARIABLES

* exporting status instruments
sort year
merge year using "brazrloc/auxil/wtf-data", nokeep
count if _m~=3
if `r(N)' > 0  STOP  // years incomplete in wtf-data.dta
drop _m

// FINALIZE ESTIMATION SAMPLE

sort wid year mes_adm mes_deslig rem_media cnpj_radic
drop mes_adm rem_media tenr2 potxper2

* category of rehiring duration
gen byte rehircat = 0 if mo2rehir==0
replace  rehircat = 1 if mo2rehir<=12 & rehircat==.
replace  rehircat = 2 if mo2rehir<=24 & rehircat==.
replace  rehircat = 3 if mo2rehir<=36 & rehircat==.
replace  rehircat = 4 if mo2rehir<=48 & rehircat==.
label var rehircat "Category of rehiring duration"
label define rehircat 0 "Within same month" 1 "Within 1 year" 2 "Within 1 to 2 years" 3 "Within 2 to 3 years" 4 "Within 3 to 4 years", modify
label values rehircat rehircat

* interaction variables and dummies
gen subs_balcadv_tarf = subs_balcadv * subs_tarfoutp
label var subs_balcadv_tarf "subs_balcadv * subs_tarfoutp"
gen firm_indexp_tarf = firm_indexp * subs_tarfoutp
label var firm_indexp_tarf "firm_indexp * subs_tarfoutp"
gen subs_balcadv_indexp = subs_balcadv * firm_indexp
label var subs_balcadv_indexp "subs_balcadv * firm_indexp"
gen subs_balcadv_indexp_tarf = subs_balcadv * subs_tarfoutp * firm_indexp
label var subs_balcadv_indexp_tarf "subs_balcad * _tarfout * _indexp"
qui tab year, generate(indyr_)
qui tab subs_ibge, generate(indsubs_) nolab
drop subs_ibge*

* reduce to estimation-sample size
drop if inddspl==0
drop inddspl
drop if subs_balcadv==. & firm_indexp==. & subs_tarfoutp==.

order wid year* mes_deslig rehircat mo2rehir cnpj_radic* inddisc indexcl subs_balcadv* subs_fdiflw* subs_reffpen* subs_tarfoutp* subs_tarfintm* subs_herfsale* subs_indprown_pis* occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_indexp* firm_lnlp* tenuryr potexper indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb subs_dollar* subs_ppieu* subs_ppinam* subs_secrealx*
save "brazrloc/data/hazard-durations-natl-subsibge.dta", replace
}

else use "brazrloc/data/hazard-durations-natl-subsibge.dta", clear

// keep only last separation per year
drop if indexcl
drop indexcl

* PSEUDO-IV REGRESSIONS: FIRST STAGE

local rnd 0
foreach depvar in `endog' {
  local rnd = `rnd' + 1
  reg `depvar' subs_balcadv `baseiv' `cntrlfrm' `cntrlwrk'
  * xtreg `depvar' subs_balcadv `baseiv' `cntrlfrm' `cntrlwrk', fe i(cnpj_radic)
  if `rnd'==1  est2vec subs_hzrd_iv1st, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp tenuryr tenr2 potexper potxper2 indprof indtech indwhit indsklb indunsklb indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) name(`depvar')
  else         est2vec subs_hzrd_iv1st, addto(subs_hzrd_iv1st) name(`depvar')
  test `baseiv'
  if `rnd'==1  est2vec subs_hzrd_iv1st, r(F p df df_r) name(`depvar')
  else         est2vec subs_hzrd_iv1st, raddto(subs_hzrd_iv1st) name(`depvar')
  predict prd_`depvar', xb
  label var prd_`depvar' "OLS prediction: `depvar'"
  predict res_`depvar', residuals
  label var res_`depvar' "OLS residuals: `depvar'"
  }
reg firm_indexp subs_balcadv `expiv' `cntrlfrm'
* xtreg firm_indexp subs_balcadv `expiv' `cntrlfrm', fe i(cnpj_radic)
est2vec subs_hzrd_iv1st, addto(subs_hzrd_iv1st) name(firm_indexp)
test `expiv'
est2vec subs_hzrd_iv1st, raddto(subs_hzrd_iv1st) name(firm_indexp)
predict prd_indexp, xb
label var prd_indexp "OLS prediction: indexp"
predict res_indexp, residuals
label var res_indexp "OLS residuals: indexp"
preserve
  keep cnpj_radic year firm_indexp `focallst' `expiv' `cntrlfrm'
  sort cnpj_radic year
  by cnpj_radic year: keep if _n==1
  reg firm_indexp subs_balcadv `expiv' `cntrlfrm'
  * xtreg firm_indexp subs_balcadv `expiv' `cntrlfrm', fe i(cnpj_radic)
  est2vec subs_hzrd_iv1st, addto(subs_hzrd_iv1st) name(firm_indexp_frmlvl)
  test `expiv'
  est2vec subs_hzrd_iv1st, raddto(subs_hzrd_iv1st) name(firm_indexp_frmlvl)
  reg firm_indexp subs_balcadv `expiv' `cntrlfrm'
  * xtreg firm_indexp subs_balcadv `expiv' `cntrlfrm', fe i(cnpj_radic)
  est2vec subs_hzrd_iv1st, addto(subs_hzrd_iv1st) name(firm_indexp_frmlvl_all)
  test `expiv'
  est2vec subs_hzrd_iv1st, raddto(subs_hzrd_iv1st) name(firm_indexp_frmlvl_all)
restore
drop cnpj_radic*

* DECLARE DATA SURVIVAL-TIME FOR 48-MONTH REALLOCATION TIME

// introduce time variable for panel structure; censor at 12/31/2001
gen int rehirtim = mdy((mes_desl+mo2rehir)-int((mes_desl+mo2rehir-.1)/12)*12,15,year+int((mes_desl+mo2rehir-.1)/12))
format rehirtim %dD/M/CY
label var rehirtim "Date of rehiring"
by wid: gen byte indreall = (mo2rehir~=.)
label var indreall "Indic.: Successful reallocation"
qui replace rehirtim = mdy(12,31,2001) if rehirtim==. & ~indreall

// stset: displacement on 14th (16th) of month, first (second) rehiring on 15th (17th) of month; days rescaled to months with 365.25/12
local scale = 365.25/12
local strt1986 = mdy(1,14,1986) // 9510
local strt1990 = mdy(1,14,1990)
local tmin1990 = (mdy(1,14,1990) - `strt1986')/`scale' // (10971-9510)/30.4375 = 1461/30.4375
qui by wid: replace rehirtim = rehirtim+2 if rehirtim[_n-1]==rehirtim  // problem cases with displacement immediately following rehiring
stset rehirtim, id(wid) failure(indreall) origin(time `strt1986') enter(time mdy(mes_desl,14,year)) exit(time .) scale(`scale')
order wid year* mes_deslig rehirtim mo2rehir rehircat inddisc subs_balcadv* subs_fdiflw* subs_reffpen* subs_tarfoutp* subs_tarfintm* subs_herfsale* subs_indprown_pis* occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_indexp* firm_lnlp* tenuryr potexper indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb subs_dollar* subs_ppieu* subs_ppinam* subs_secrealx*
sort wid year year_rehir

// summarize survival-time data (survival: individual remains in pool to-be-reallocated; failure: successful rehiring)
stdes
stsum
qui stgen _numfail = nfailures()
label var _numfail "No. of failures"
stsum, by(_numfail)
egen _newid = group(wid _numfail)
qui bysort _newid: replace _t = _t - _t0[1]
qui bysort _newid: gen _newt0 = _t0 - _t0[1]
stset _t, failure(_d) id(_newid) time0(_newt0)
stsum, by(_numfail)
drop _numfail
stset rehirtim, id(wid) failure(indreall) origin(time `strt1986') enter(time mdy(mes_desl,14,year)) exit(time .) scale(`scale')

// graph Kaplan-Meier survival estimates (survival: individual remains in pool to-be-reallocated; failure: successful rehiring)
* streset, origin(time `strt1986')
sts graph if rehircat<=4, xtitle("Reallocation duration (in months)") xlab(0 12 24 36 48 72 144) graphregion(color(white)) scheme(sj) title("")
graph export "brazrloc/graphs/v4/natl/hazard/kaplanmeier1986.eps", replace
* sts graph if rehircat<=4 & year>=1990, tmin(`tmin1990'/`scale') xtitle("Reallocation duration (in months)") xlab(0 12 24 36 48 72 144) graphregion(color(white)) scheme(sj) title("")
streset, origin(time `strt1990')
sts graph if rehircat<=4 & year>=1990, xtitle("Reallocation duration (in months)") xlab(0 12 24 36 48 72 144) graphregion(color(white)) scheme(sj) title("")
graph export "brazrloc/graphs/v4/natl/hazard/kaplanmeier1990.eps", replace


* SURVIVAL REGRESSIONS

stset rehirtim, id(wid) failure(indreall) origin(time `strt1990') enter(time mdy(mes_desl,14,year)) exit(time .) scale(`scale')

// Akaike's information criterion for parametric regression selection

mat aic_hzrd_b = J(11,5,.)
matrix rownames aic_hzrd_b = subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen ancill kappa e(ll) e(aic)
matrix colnames aic_hzrd_b = exponential weibull lognormal loglogistic gamma
mat aic_hzrd_se = aic_hzrd_b
mat aic_hzrd_e = aic_hzrd_b[1,1..5]
matrix rownames aic_hzrd_e = e(N)

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(exponential) robust iterate(`maxiter') time
est2vec _tmp, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen) e(N ll df_m) name(exponential) replace
mat aic_hzrd_b[1,1] = _tmp_b
mat aic_hzrd_se[1,1] = _tmp_se
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(ll)"),1] = _tmp_e[rownumb(_tmp_e,"e(ll)"),1]
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(aic)"),1] = -2*_tmp_e[rownumb(_tmp_e,"e(ll)"),1] + 2*(_tmp_e[rownumb(_tmp_e,"e(df_m)"),1]+0+1)
mat aic_hzrd_e[1,1] = _tmp_e[1,1]

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(weibull) robust iterate(`maxiter') time
est2vec _tmp, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen ln_p:_cons) e(N ll df_m) name(weibull) replace
mat aic_hzrd_b[1,2] = _tmp_b
mat aic_hzrd_se[1,2] = _tmp_se
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(ll)"),2] = _tmp_e[rownumb(_tmp_e,"e(ll)"),1]
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(aic)"),2] = -2*_tmp_e[rownumb(_tmp_e,"e(ll)"),1] + 2*(_tmp_e[rownumb(_tmp_e,"e(df_m)"),1]+1+1)
mat aic_hzrd_e[1,2] = _tmp_e[1,1]

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(lognormal) robust iterate(`maxiter')
est2vec _tmp, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen ln_sig:_cons) e(N ll df_m) name(lognormal) replace
mat aic_hzrd_b[1,3] = _tmp_b
mat aic_hzrd_se[1,3] = _tmp_se
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(ll)"),3] = _tmp_e[rownumb(_tmp_e,"e(ll)"),1]
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(aic)"),3] = -2*_tmp_e[rownumb(_tmp_e,"e(ll)"),1] + 2*(_tmp_e[rownumb(_tmp_e,"e(df_m)"),1]+1+1)
mat aic_hzrd_e[1,3] = _tmp_e[1,1]

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(loglogistic) robust iterate(`maxiter')
est2vec _tmp, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen ln_gam:_cons) e(N ll df_m) name(loglogistic) replace
mat aic_hzrd_b[1,4] = _tmp_b
mat aic_hzrd_se[1,4] = _tmp_se
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(ll)"),4] = _tmp_e[rownumb(_tmp_e,"e(ll)"),1]
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(aic)"),4] = -2*_tmp_e[rownumb(_tmp_e,"e(ll)"),1] + 2*(_tmp_e[rownumb(_tmp_e,"e(df_m)"),1]+1+1)
mat aic_hzrd_e[1,4] = _tmp_e[1,1]

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec _tmp, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen ln_sig:_cons kappa:_cons) e(N ll df_m) name(gamma) replace
mat aic_hzrd_b[1,5] = _tmp_b
mat aic_hzrd_se[1,5] = _tmp_se
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(ll)"),5] = _tmp_e[rownumb(_tmp_e,"e(ll)"),1]
mat aic_hzrd_b[rownumb(aic_hzrd_b,"e(aic)"),5] = -2*_tmp_e[rownumb(_tmp_e,"e(ll)"),1] + 2*(_tmp_e[rownumb(_tmp_e,"e(df_m)"),1]+2+1)
mat aic_hzrd_e[1,5] = _tmp_e[1,1]

mat drop _tmp_b _tmp_se _tmp_e

// main regressions

streg `rehirlst' `rehrendg' `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990 & rehircat<=4, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, vars(subs_balcadv_rehir firm_indexp_rehir subs_tarfoutp_rehir subs_tarfintm_rehir subs_reffpen_rehir subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp tenuryr tenr2 potexper potxper2 indprof indtech indwhit indsklb indunsklb indprim indhigh indscoll indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2_p rc ic) name(streg_rehir)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In streg sample"

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_focal)

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990 & indsmpl, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_focal_rhirsmpl)

// comparisons with more focal variables

streg `rehirlst' `rehrendg' `focallst' `addlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990 & indsmpl, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_addlrehir)

streg `focallst' `addlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_addl)

streg `focallst' `addlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990 & indsmpl, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_addl_rhirsmpl)

streg `rehirlst' `rehrendg' `focallst' `addlst' `morelst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990 & indsmpl, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_morerehir)

streg `focallst' `addlst' `morelst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_more)

streg `focallst' `addlst' `morelst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990 & indsmpl, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_more_rhirsmpl)

// comparisons with omitted focal variables

streg subs_balcadv `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_balcadv)

streg subs_balcadv subs_balcadv_tarf `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_balcadv_tarf)

streg firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_indexp)

streg firm_indexp firm_indexp_tarf subs_tarfoutp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_indexp_tarf)

// robustness checks

streset, origin(time `strt1986')
streg subs_balcadv subs_balcadv_tarf `endog' `cntrlfrm' `cntrlwrk' indyr*, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_allyrs)
streset, origin(time `strt1990')

streg `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_nofocal)

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* indsubs* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_indsubs)

streg `focallst' subs_indprown_pis `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_indprown)

streg `focallst' occ_indoutsrc `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_indoutsrc)

streg `focallst' firm_lnlp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_lnlp)

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' `addlwrkr' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_addlwrkr)

streg subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_nointrct)

// iv

streg subs_balcadv firm_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_iv_tarfetc)

streg subs_balcadv prd_indexp res_indexp `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_iv_indexp)

streg subs_balcadv prd_indexp res_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlfrm' `cntrlwrk' indyr* if year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_iv_all)

// education group subsamples

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indprim & year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_indprim)

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indhigh & year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_indhigh)

streg `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if indscoll | indgrad & year>=1990, dist(gamma) robust iterate(`maxiter')
est2vec subs_hzrd, addto(subs_hzrd) name(streg_indcoll)

// Cox regressions (reporting in log file only)

stcox `rehirlst' `rehrendg' `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, robust iterate(`maxiter') scaledsch(_sca*) schoenfeld(_sch*) nohr
stphtest, detail
drop _sca* _sch*

stcox `focallst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, robust iterate(`maxiter') scaledsch(_sca*) schoenfeld(_sch*) nohr
stphtest, detail
drop _sca* _sch*


* SAVE RESULTS

preserve
foreach type in b se e {
  matsave aic_hzrd_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  matsave subs_hzrd_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }
foreach type in b se e r {
  matsave subs_hzrd_iv1st_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }
restore
drop prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp indsmpl

log close
cd "$root"
