version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl-maleprime"
capture mkdir "brazrloc/tex/v4/gdp"

capture log close
log using "brazrloc/logs/prediction-stats-paper-natlmaleprime.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local paperlst "subs_balcadv firm_indexp"
local focallst "subs_balcadv firm_indexp"
local rehirlst "subs_balcadv_rehir firm_indexp_rehir"
local rehrendg "subs_tarfoutp_rehir subs_tarfintm_rehir subs_reffpen_rehir"
local cntrlfrm "subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local cntrlwrk "indprof indtech indwhit indsklb"
local cntrlreh "tenuryr potexper indprof indtech indwhit indsklb"
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"


* SEPARATIONS NATL

// coefficient estimates
matload subsdspl_paper_b, p(brazrloc/estmat/v4/reg/natl-maleprime) over dropall
matorder subsdspl_paper_b, m(subs_dspl) ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp) over
matorder subs_dspl, m(subs_dspl) ifc(clogit_paper clogit_secfe clogit_noyreff xt xtiv) over
mat drop subsdspl_paper_b

// clogit sample (with recreated sector codes)
use if ~indexcl using "brazrloc/data/separations-natl-maleprime-subsibge.dta", clear
qui clogit inddspl `paperlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
gen byte subsibge = .
forvalues i = 1/26 {
  qui replace subsibge = `i' if indsubs_`i'==1
  }
qui predict phat, p
* gen byte trend = year - 1986
* label var trend "Annual Trend"
qui clogit inddspl `paperlst' `endog' `cntrlfrm' `cntrlwrk' if year>=1990, group(wid) robust iterate(`maxiter')
qui predict phatnoyr, p

// sample means
foreach yr in 90 92 94 98 {
  mat tradvars`yr' = J(7,27,.)
  local i 0
  foreach var in subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp inddspl phat phatnoyr {
    local i = `i' + 1
    matname tradvars`yr' `var', rows(`i') explicit
    matname tradvars`yr' yr`yr':allsec, columns(1) explicit
    if substr("`var'",1,4)~="phat" {
      qui summ `var' if year==19`yr' & indsmpl
      disp in gr "Coefficient of variation of " in ye "`var'" in gr " in " in ye "19`yr'" in gr ": " in ye `r(sd)'/`r(mean)'
      }
    else qui summ `var' if indsmpl, meanonly
    mat tradvars`yr'[`i',1] = r(mean)
    forvalues subsec = 1/26 {
      local namesec "sec`subsec'"
      if `subsec'<10  local namesec "sec0`subsec'"
      local col = `subsec' + 1
      matname tradvars`yr' yr`yr':`namesec', columns(`col') explicit
      qui summ `var' if year==19`yr' & subsibge==`subsec' & indsmpl, meanonly
      mat tradvars`yr'[`i',`col'] = r(mean)
      }
    }
  }
foreach yr in 92 94 98 {
  mat tradvdif`yr'90 = tradvars`yr'[1..4,1...] - tradvars90[1..4,1...]
  mat predall`yr'90 = subs_dspl ' * tradvdif`yr'90
  mat predtrad`yr'90 = subs_dspl[1..3,1...] ' * tradvdif`yr'90[1..3,1...]
  mat predsec`yr'90 = subs_dspl[1..2,1...] ' * tradvdif`yr'90[1..2,1...]
  }
  
// report results
mat list subs_dspl
mat list tradvdif9890
mat list predall9890
mat list predtrad9890
mat list predsec9890
mat list tradvdif9490
mat list predall9490
mat list predtrad9490
mat list predsec9490

// rename matrices to keep results
mat rename subs_dspl subsdspl_coef_tbl
mat rename tradvars90 subsdspl_tradvars90_tbl
mat rename tradvars92 subsdspl_tradvars92_tbl
mat rename tradvars94 subsdspl_tradvars94_tbl
mat rename tradvars98 subsdspl_tradvars98_tbl


* ACCESSIONS NATL

// coefficient estimates
matload subshire_paper_b, p(brazrloc/estmat/v4/reg/natl-maleprime) over dropall
matorder subshire_paper_b, m(subs_hire) ifr(subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp) over
matorder subs_hire, m(subs_hire) ifc(clogit_paper clogit_secfe clogit_noyreff xt xtiv) over
mat drop subshire_paper_b

// clogit sample (with recreated sector codes)
use if ~indexcl using "brazrloc/data/accessions-natl-maleprime-subsibge.dta", clear
qui clogit indhire `paperlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
gen byte subsibge = .
forvalues i = 1/26 {
  qui replace subsibge = `i' if indsubs_`i'==1
  }
qui predict phat, p
* gen byte trend = year - 1986
* label var trend "Annual Trend"
qui clogit indhire `paperlst' `endog' `cntrlfrm' `cntrlwrk' if year>=1990, group(wid) robust iterate(`maxiter')
qui predict phatnoyr, p

// sample means
foreach yr in 90 92 94 98 {
  mat tradvars`yr' = J(7,27,.)
  local i 0
  foreach var in subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp indhire phat phatnoyr {
    local i = `i' + 1
    matname tradvars`yr' `var', rows(`i') explicit
    matname tradvars`yr' yr`yr':allsec, columns(1) explicit
    if substr("`var'",1,4)~="phat" {
      qui summ `var' if year==19`yr' & indsmpl
      disp in gr "Coefficient of variation of " in ye "`var'" in gr " in " in ye "19`yr'" in gr ": " in ye `r(sd)'/`r(mean)'
      }
    else qui summ `var' if indsmpl, meanonly
    mat tradvars`yr'[`i',1] = r(mean)
    forvalues subsec = 1/26 {
      local namesec "sec`subsec'"
      if `subsec'<10  local namesec "sec0`subsec'"
      local col = `subsec' + 1
      matname tradvars`yr' yr`yr':`namesec', columns(`col') explicit
      qui summ `var' if year==19`yr' & subsibge==`subsec' & indsmpl, meanonly
      mat tradvars`yr'[`i',`col'] = r(mean)
      }
    }
  }
foreach yr in 92 94 98 {
  mat tradvdif`yr'90 = tradvars`yr'[1..4,1...] - tradvars90[1..4,1...]
  mat predall`yr'90 = subs_hire ' * tradvdif`yr'90
  mat predtrad`yr'90 = subs_hire[1..3,1...] ' * tradvdif`yr'90[1..3,1...]
  mat predsec`yr'90 = subs_hire[1..2,1...] ' * tradvdif`yr'90[1..2,1...]
  }
  
// report results
mat list subs_hire
mat list tradvdif9890
mat list predall9890
mat list predtrad9890
mat list predsec9890
mat list tradvdif9490
mat list predall9490
mat list predtrad9490
mat list predsec9490

// rename matrices to keep results
mat rename subs_hire subshire_coef_tbl
mat rename tradvars90 subshire_tradvars90_tbl
mat rename tradvars92 subshire_tradvars92_tbl
mat rename tradvars94 subshire_tradvars94_tbl
mat rename tradvars98 subshire_tradvars98_tbl


* SAVE MAIN MATRICES

foreach margin in dspl hire {
  foreach mat in _coef _tradvars90 _tradvars92 _tradvars94 _tradvars98 {
    est2tex subs`margin'`mat', replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)
    }
  }

log close
