version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl10pct"

capture log close
log using "brazrloc/logs/separations-accessions-aer-natl-rr-comp-cluster-10pct.log", replace

local maxiter $maxiter

capture program drop ivreplc
program define ivreplc
  foreach reg in $regdef {
    replace imp_`reg' = imp_`reg' * ini_lnempl
    }
end

// AUXILIARY ANNUAL DATA

tempfile auxdat
insheet using "brazrloc/auxil/origs/pib.csv", clear
keep ano populacao pib_corrente_usd
rename ano year
label var year "Calendar Year"
rename populacao population
label var population "Population [mio]"
rename pib_corrente_usd gdp_usd
replace gdp_usd = gdp_usd/1000000
label var gdp_usd "GDP [current USD bio]"
keep if year>=1986 & year<=1998
sort year
merge year using "brazrloc/auxil/globfin-annual", nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m
keep year __brl_d population _ibx50d
sort year
save `auxdat'


// SUBSIBGE REGRESSIONS

local basendog "mixd_tarfoutp mixd_tarfintm firm_indexp"  // cut: mixd_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "mixd_secrealx mixd_fdiflw mixd_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "mixd_ppieu mixd_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "mixd_tarfoutp_indexp mixd_tarfintm_indexp"
local intract2 "mixd_tarfoutp_balcadv mixd_tarfintm_balcadv"
local intract2_90  "mixd_tarfoutp_balcadv_90 mixd_tarfintm_balcadv_90"
local intract3 "mixd_tarfoutp_indexp_balcadv mixd_tarfintm_indexp_balcadv"
local intract3_90  "mixd_tarfoutp_indexp_balcadv_90 mixd_tarfintm_indexp_balcadv_90"
local intract4 "mixd_tarfoutp_notindprim mixd_tarfintm_notindprim"  // if ~indprim
local intract5 "mixd_tarfoutp_indyoung mixd_tarfintm_indyoung"  // if potexper < 10
local intract6 "mixd_tarfoutp_indwhite mixd_tarfintm_indwhite"  // if indprof | indtech | indwhit
local intract7 "mixd_tarfoutp_indfemal mixd_tarfintm_indfemal"  // if indfemal
local intract8 "mixd_tarfoutp_notindprim mixd_tarfintm_notindprim firm_indexp_notindprim mixd_balcadv_notindprim"
local intract9 "mixd_tarfoutp_indexp_notindprim mixd_tarfoutp_balcadv_notindprim mixd_tarfintm_indexp_notindprim mixd_tarfintm_balcadv_notindprim"
local addlreg  "mixd_indprown_pis occ_indoutsrc"
local auxyr    "__brl_d population _ibx50d"

* separations natl

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge-10pct.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf indlayoff indquit
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* update sector information with CNAE when possible
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta", keep(mod_clas_cnae_95) nokeep
drop _m
rename ano year
rename mod_clas_cnae_95 cnae
replace cnae=. if cnae==-1 | cnae==0
replace cnae=int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data.dta", nokeep
foreach var in fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis dollar ppieu ppinam secrealx {
  rename subs_`var' mixd_`var'
  replace mixd_`var' = cnae_`var' if cnae_`var'~=.
  drop cnae_`var'
  }
drop _m cnae

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"

* interactions
gen mixd_tarfoutp_indexp = mixd_tarfoutp * firm_indexp
label var mixd_tarfoutp_indexp "tarfoutp * indexp"
gen mixd_tarfintm_indexp = mixd_tarfintm * firm_indexp
label var mixd_tarfintm_indexp "tarfintm * indexp"
gen mixd_tarfoutp_balcadv = mixd_tarfoutp * subs_balcadv
label var mixd_tarfoutp_balcadv "tarfoutp * balcadv"
gen mixd_tarfintm_balcadv = mixd_tarfintm * subs_balcadv
label var mixd_tarfintm_balcadv "tarfintm * balcadv"
gen mixd_tarfoutp_indexp_balcadv = mixd_tarfoutp * firm_indexp * subs_balcadv
label var mixd_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen mixd_tarfintm_indexp_balcadv = mixd_tarfintm * firm_indexp * subs_balcadv
label var mixd_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen mixd_tarfoutp_notindprim = mixd_tarfoutp * (~indprim) // if ~indprim
label var mixd_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen mixd_tarfintm_notindprim = mixd_tarfintm * (~indprim) // if ~indprim
label var mixd_tarfintm_notindprim "tarfintm * (~indprim)"
gen mixd_tarfoutp_indyoung = mixd_tarfoutp * (potexper<10) // if potexper < 10
label var mixd_tarfoutp_indyoung "mixd_tarfoutp * (potexper<10)"
gen mixd_tarfintm_indyoung = mixd_tarfintm * (potexper<10) // if potexper < 10
label var mixd_tarfintm_indyoung "mixd_tarfintm * (potexper<10)"
gen mixd_tarfoutp_indwhite = mixd_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var mixd_tarfoutp_indwhite "mixd_tarfoutp * (indwhit+)"
gen mixd_tarfintm_indwhite = mixd_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var mixd_tarfintm_indwhite "mixd_tarfintm * (indwhit+)"
gen mixd_tarfoutp_indfemal = mixd_tarfoutp * (indfemal) // if indfemal
label var mixd_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen mixd_tarfintm_indfemal = mixd_tarfintm * (indfemal) // if indfemal
label var mixd_tarfintm_indfemal "tarfintm * (indfemal)"
gen mixd_tarfoutp_balcadv_90 = mixd_tarfoutp * subs_balcadv_90
label var mixd_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen mixd_tarfintm_balcadv_90 = mixd_tarfintm * subs_balcadv_90
label var mixd_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen mixd_tarfoutp_indexp_balcadv_90 = mixd_tarfoutp * firm_indexp * subs_balcadv_90
label var mixd_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen mixd_tarfintm_indexp_balcadv_90 = mixd_tarfintm * firm_indexp * subs_balcadv_90
label var mixd_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen mixd_tarfoutp_volrcadv_90 = mixd_tarfoutp * subs_volrcadv_90
label var mixd_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen mixd_tarfintm_volrcadv_90 = mixd_tarfintm * subs_volrcadv_90
label var mixd_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen mixd_tarfoutp_indexp_volrcadv_90 = mixd_tarfoutp * firm_indexp * subs_volrcadv_90
label var mixd_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen mixd_tarfintm_indexp_volrcadv_90 = mixd_tarfintm * firm_indexp * subs_volrcadv_90
label var mixd_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* cluster variable
gen clusterid = cnpj_radic  // alt: gen clusterid = int(real(string(subs_ibge)+string(year))); gen clusterid = subs_ibge
label var clusterid "Firm cluster"
drop subs_ibge

* regressions

clogit inddspl `basendog' `secexo90' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrrclst, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_balcadv_90 subs_volrcadv_90 subs_reffpen subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indcoll plant_indhigh plant_indwhittot firm_lnlp tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv subs_tarfoutp_notindprim subs_tarfintm_notindprim subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_yrfe_exo90)
est2vec subsdspl_aerrrclst, r(F p df df_r) name(clogit_yrfe_exo90)

clogit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(clogit_secyrfe0)
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(clogit_secyrfe0)

xtivreg inddspl `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(xtiv_secyrfe0)
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(xtiv_secyrfe0)

xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(xt_secyrfe0)
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(xt_secyrfe0)

xtreg inddspl firm_lnlp `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(xtreg_lnlp0)
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(xtreg_lnlp0)

xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(xt_secyrtrdfe0)
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(xt_secyrtrdfe0)

xtreg inddspl `basendog' `intract1' `intract2_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(xt_intract20_90) 
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(xt_intract20_90)

xtreg inddspl `basendog' `intract1' `intract2_90' `intract3_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(xt_intract30_90)
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(xt_intract30_90)

xtreg inddspl `basendog' `intract4' `intract5' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(xt_intract40)
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(xt_intract40)

xtreg inddspl `basendog' `intract4' `intract5' `intract6' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subsdspl_aerrrclst, addto(subsdspl_aerrrclst) name(xt_intract70)
est2vec subsdspl_aerrrclst, raddto(subsdspl_aerrrclst) name(xt_intract70)


* accessions natl

local cntrlwrk "potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge-10pct.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* update sector information with CNAE when possible
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta", keep(mod_clas_cnae_95) nokeep
drop _m
rename ano year
rename mod_clas_cnae_95 cnae
replace cnae=. if cnae==-1 | cnae==0
replace cnae=int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data.dta", nokeep
foreach var in fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis dollar ppieu ppinam secrealx {
  rename subs_`var' mixd_`var'
  replace mixd_`var' = cnae_`var' if cnae_`var'~=.
  drop cnae_`var'
  }
drop _m cnae

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"

* interactions
gen mixd_tarfoutp_indexp = mixd_tarfoutp * firm_indexp
label var mixd_tarfoutp_indexp "tarfoutp * indexp"
gen mixd_tarfintm_indexp = mixd_tarfintm * firm_indexp
label var mixd_tarfintm_indexp "tarfintm * indexp"
gen mixd_tarfoutp_balcadv = mixd_tarfoutp * subs_balcadv
label var mixd_tarfoutp_balcadv "tarfoutp * balcadv"
gen mixd_tarfintm_balcadv = mixd_tarfintm * subs_balcadv
label var mixd_tarfintm_balcadv "tarfintm * balcadv"
gen mixd_tarfoutp_indexp_balcadv = mixd_tarfoutp * firm_indexp * subs_balcadv
label var mixd_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen mixd_tarfintm_indexp_balcadv = mixd_tarfintm * firm_indexp * subs_balcadv
label var mixd_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen mixd_tarfoutp_notindprim = mixd_tarfoutp * (~indprim) // if ~indprim
label var mixd_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen mixd_tarfintm_notindprim = mixd_tarfintm * (~indprim) // if ~indprim
label var mixd_tarfintm_notindprim "tarfintm * (~indprim)"
gen mixd_tarfoutp_indyoung = mixd_tarfoutp * (potexper<10) // if potexper < 10
label var mixd_tarfoutp_indyoung "mixd_tarfoutp * (potexper<10)"
gen mixd_tarfintm_indyoung = mixd_tarfintm * (potexper<10) // if potexper < 10
label var mixd_tarfintm_indyoung "mixd_tarfintm * (potexper<10)"
gen mixd_tarfoutp_indwhite = mixd_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var mixd_tarfoutp_indwhite "mixd_tarfoutp * (indwhit+)"
gen mixd_tarfintm_indwhite = mixd_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var mixd_tarfintm_indwhite "mixd_tarfintm * (indwhit+)"
gen mixd_tarfoutp_indfemal = mixd_tarfoutp * (indfemal) // if indfemal
label var mixd_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen mixd_tarfintm_indfemal = mixd_tarfintm * (indfemal) // if indfemal
label var mixd_tarfintm_indfemal "tarfintm * (indfemal)"
gen mixd_tarfoutp_balcadv_90 = mixd_tarfoutp * subs_balcadv_90
label var mixd_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen mixd_tarfintm_balcadv_90 = mixd_tarfintm * subs_balcadv_90
label var mixd_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen mixd_tarfoutp_indexp_balcadv_90 = mixd_tarfoutp * firm_indexp * subs_balcadv_90
label var mixd_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen mixd_tarfintm_indexp_balcadv_90 = mixd_tarfintm * firm_indexp * subs_balcadv_90
label var mixd_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen mixd_tarfoutp_volrcadv_90 = mixd_tarfoutp * subs_volrcadv_90
label var mixd_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen mixd_tarfintm_volrcadv_90 = mixd_tarfintm * subs_volrcadv_90
label var mixd_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen mixd_tarfoutp_indexp_volrcadv_90 = mixd_tarfoutp * firm_indexp * subs_volrcadv_90
label var mixd_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen mixd_tarfintm_indexp_volrcadv_90 = mixd_tarfintm * firm_indexp * subs_volrcadv_90
label var mixd_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* cluster variable
gen clusterid = cnpj_radic  // alt: gen clusterid = int(real(string(subs_ibge)+string(year))); gen clusterid = subs_ibge
label var clusterid "Firm cluster"
drop subs_ibge

* regressions

clogit indhire `basendog' `secexo90' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrrclst, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_balcadv_90 subs_volrcadv_90 subs_reffpen subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indcoll plant_indhigh plant_indwhittot firm_lnlp tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv subs_tarfoutp_notindprim subs_tarfintm_notindprim subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_yrfe_exo90)
est2vec subshire_aerrrclst, r(F p df df_r) name(clogit_yrfe_exo90)

clogit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(clogit_secyrfe0)
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(clogit_secyrfe0)

xtivreg indhire `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(xtiv_secyrfe0)
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(xtiv_secyrfe0)

xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(xt_secyrfe0)
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(xt_secyrfe0)

xtreg indhire firm_lnlp `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(xtreg_lnlp0)
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(xtreg_lnlp0)

xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(xt_secyrtrdfe0)
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(xt_secyrtrdfe0)

xtreg indhire `basendog' `intract1' `intract2_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(xt_intract20_90) 
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(xt_intract20_90)

xtreg indhire `basendog' `intract1' `intract2_90' `intract3_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(xt_intract30_90)
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(xt_intract30_90)

xtreg indhire `basendog' `intract4' `intract5' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(xt_intract40)
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(xt_intract40)

xtreg indhire `basendog' `intract4' `intract5' `intract6' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) cluster(clusterid)
est2vec subshire_aerrrclst, addto(subshire_aerrrclst) name(xt_intract70)
est2vec subshire_aerrrclst, raddto(subshire_aerrrclst) name(xt_intract70)


// Save results

foreach type in b se e r {
  matsave subsdspl_aerrrclst_`type', p(brazrloc/estmat/v4/reg/natl10pct) t(double) replace dropall
  matsave subshire_aerrrclst_`type', p(brazrloc/estmat/v4/reg/natl10pct) t(double) replace dropall
  }

log close
