version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/separations-accessions-aer-natl-rr-intract.log", replace

local maxiter $maxiter

capture program drop ivreplc
program define ivreplc
  foreach reg in $regdef {
    replace imp_`reg' = imp_`reg' * ini_lnempl
    }
end


// SUBSIBGE REGRESSIONS

local basendog "subs_tarfoutp subs_tarfintm firm_indexp"  // cut: subs_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "subs_ppieu subs_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "subs_tarfoutp_indexp subs_tarfintm_indexp"
local intract2 "subs_tarfoutp_balcadv subs_tarfintm_balcadv"
local intract2_90  "subs_tarfoutp_balcadv_90 subs_tarfintm_balcadv_90"
local intract2_90a "subs_tarfoutp_volrcadv_90 subs_tarfintm_volrcadv_90"
local intract3 "subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv"
local intract3_90  "subs_tarfoutp_indexp_balcadv_90 subs_tarfintm_indexp_balcadv_90"
local intract3_90a "subs_tarfoutp_indexp_volrcadv_90 subs_tarfintm_indexp_volrcadv_90"
local intract4 "subs_tarfoutp_notindprim subs_tarfintm_notindprim"  // if ~indprim
local intract5 "subs_tarfoutp_indyoung subs_tarfintm_indyoung"  // if potexper < 10
local intract6 "subs_tarfoutp_indwhite subs_tarfintm_indwhite"  // if indprof | indtech | indwhit
local intract7 "subs_tarfoutp_indfemal subs_tarfintm_indfemal"  // if indfemal
local intract8 "subs_tarfoutp_notindprim subs_tarfintm_notindprim firm_indexp_notindprim subs_balcadv_notindprim"
local intract9 "subs_tarfoutp_indexp_notindprim subs_tarfoutp_balcadv_notindprim subs_tarfintm_indexp_notindprim subs_tarfintm_balcadv_notindprim"
local addlreg  "subs_indprown_pis occ_indoutsrc"


* separations natl

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf indlayoff indquit
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"
drop subs_ibge

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen firm_indexp_notindprim = firm_indexp * (~indprim) // if ~indprim
label var firm_indexp_notindprim "indexp * (~indprim)"
gen subs_balcadv_notindprim = subs_balcadv * (~indprim) // if ~indprim
label var subs_balcadv_notindprim "balcadv * (~indprim)"
gen subs_tarfoutp_indexp_notindprim = subs_tarfoutp * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfoutp_indexp_notindprim "tarfoutp * indexp * (~indprim)"
gen subs_tarfoutp_balcadv_notindprim = subs_tarfoutp * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfoutp_balcadv_notindprim "tarfoutp * balcadv * (~indprim)"
gen subs_tarfintm_indexp_notindprim = subs_tarfintm * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfintm_indexp_notindprim "tarfintm * indexp * (~indprim)"
gen subs_tarfintm_balcadv_notindprim = subs_tarfintm * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfintm_balcadv_notindprim "tarfintm * balcadv * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"
gen subs_tarfoutp_indfemal = subs_tarfoutp * (indfemal) // if indfemal
label var subs_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen subs_tarfintm_indfemal = subs_tarfintm * (indfemal) // if indfemal
label var subs_tarfintm_indfemal "tarfintm * (indfemal)"
gen subs_tarfoutp_balcadv_90 = subs_tarfoutp * subs_balcadv_90
label var subs_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen subs_tarfintm_balcadv_90 = subs_tarfintm * subs_balcadv_90
label var subs_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen subs_tarfoutp_indexp_balcadv_90 = subs_tarfoutp * firm_indexp * subs_balcadv_90
label var subs_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen subs_tarfintm_indexp_balcadv_90 = subs_tarfintm * firm_indexp * subs_balcadv_90
label var subs_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen subs_tarfoutp_volrcadv_90 = subs_tarfoutp * subs_volrcadv_90
label var subs_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen subs_tarfintm_volrcadv_90 = subs_tarfintm * subs_volrcadv_90
label var subs_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen subs_tarfoutp_indexp_volrcadv_90 = subs_tarfoutp * firm_indexp * subs_volrcadv_90
label var subs_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen subs_tarfintm_indexp_volrcadv_90 = subs_tarfintm * firm_indexp * subs_volrcadv_90
label var subs_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* regressions

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_balcadv_90 subs_volrcadv_90 subs_balcadv_up subs_balcadv_dn subs_reffpen subs_secrealx subs_fdiflw subs_herfsale  plant_lnempl plant_indcoll plant_indhigh plant_indwhittot tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv  subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv  subs_tarfoutp_balcadv_90 subs_tarfintm_balcadv_90 subs_tarfoutp_indexp_balcadv_90 subs_tarfintm_indexp_balcadv_90 subs_tarfoutp_volrcadv_90 subs_tarfintm_volrcadv_90 subs_tarfoutp_indexp_volrcadv_90 subs_tarfintm_indexp_volrcadv_90  subs_tarfoutp_notindprim subs_tarfintm_notindprim  subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite  subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_nofe)
est2vec subsdspl_aerrr_intract, r(F p df df_r) name(clogit_nofe)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl
summ2tex inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `ivlst' `intract1' `intract2' `intract2_90' `intract2_90a' `intract3' `intract3_90' `intract3_90a' `intract4' `intract5' `intract6' `intract7' `intract8' `intract9' `addlreg' if e(sample), c(mean sd N p50) name(summ_dspl_intract) p(brazrloc/estmat/v4/reg/natl) replace detail

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_yrfe)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_yrfe)

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_secyrfe)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_secyrfe)

clogit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_secyrfe0)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_secyrfe0)

clogit inddspl `basendog' `secexog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract2)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract2)

clogit inddspl `basendog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract20)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract20)

clogit inddspl `basendog' `intract1' `intract2_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract20_90)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract20_90)

clogit inddspl `basendog' `intract1' `intract2_90a' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract20_90a)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract20_90a)

clogit inddspl `basendog' `secexog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract3)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract3)

clogit inddspl `basendog' subs_balcadv_up subs_balcadv_dn `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract3_updn)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract3_updn)

clogit inddspl `basendog' `secexog' `intract1' `intract2' `intract3' subs_reffpen `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract3_reffpen)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract3_reffpen)

clogit inddspl `basendog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract30)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract30)

clogit inddspl `basendog' `intract1' `intract2_90' `intract3_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract30_90)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract30_90)

clogit inddspl `basendog' `intract1' `intract2_90' `intract3_90' subs_reffpen `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract30_90_reffpen)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract30_90_reffpen)

clogit inddspl `basendog' `intract1' `intract2_90a' `intract3_90a' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract30_90a)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract30_90a)

clogit inddspl `basendog' `secexog' `intract4' `intract5' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract4)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract4)

clogit inddspl `basendog' `intract4' `intract5' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract40)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract40)

clogit inddspl `basendog' `secexog' `intract4' `intract5' `intract6' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract7)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract7)

clogit inddspl `basendog' `intract4' `intract5' `intract6' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract70)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract70)

clogit inddspl `basendog' `secexog' `intract8' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract8)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract8)

clogit inddspl `basendog' `intract8' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract80)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract80)

clogit inddspl `basendog' `secexog' `intract8' `intract9' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract9)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract9)

clogit inddspl `basendog' `intract8' `intract9' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr_intract, addto(subsdspl_aerrr_intract) name(clogit_intract90)
est2vec subsdspl_aerrr_intract, raddto(subsdspl_aerrr_intract) name(clogit_intract90)


* accessions natl

local cntrlwrk "potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"
drop subs_ibge

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_indfemal = subs_tarfoutp * (indfemal) // if indfemal
label var subs_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen subs_tarfintm_indfemal = subs_tarfintm * (indfemal) // if indfemal
label var subs_tarfintm_indfemal "tarfintm * (indfemal)"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen firm_indexp_notindprim = firm_indexp * (~indprim) // if ~indprim
label var firm_indexp_notindprim "indexp * (~indprim)"
gen subs_balcadv_notindprim = subs_balcadv * (~indprim) // if ~indprim
label var subs_balcadv_notindprim "balcadv * (~indprim)"
gen subs_tarfoutp_indexp_notindprim = subs_tarfoutp * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfoutp_indexp_notindprim "tarfoutp * indexp * (~indprim)"
gen subs_tarfoutp_balcadv_notindprim = subs_tarfoutp * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfoutp_balcadv_notindprim "tarfoutp * balcadv * (~indprim)"
gen subs_tarfintm_indexp_notindprim = subs_tarfintm * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfintm_indexp_notindprim "tarfintm * indexp * (~indprim)"
gen subs_tarfintm_balcadv_notindprim = subs_tarfintm * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfintm_balcadv_notindprim "tarfintm * balcadv * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"
gen subs_tarfoutp_balcadv_90 = subs_tarfoutp * subs_balcadv_90
label var subs_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen subs_tarfintm_balcadv_90 = subs_tarfintm * subs_balcadv_90
label var subs_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen subs_tarfoutp_indexp_balcadv_90 = subs_tarfoutp * firm_indexp * subs_balcadv_90
label var subs_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen subs_tarfintm_indexp_balcadv_90 = subs_tarfintm * firm_indexp * subs_balcadv_90
label var subs_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen subs_tarfoutp_volrcadv_90 = subs_tarfoutp * subs_volrcadv_90
label var subs_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen subs_tarfintm_volrcadv_90 = subs_tarfintm * subs_volrcadv_90
label var subs_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen subs_tarfoutp_indexp_volrcadv_90 = subs_tarfoutp * firm_indexp * subs_volrcadv_90
label var subs_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen subs_tarfintm_indexp_volrcadv_90 = subs_tarfintm * firm_indexp * subs_volrcadv_90
label var subs_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"
gen subs_balcadv_up = subs_balcadv * (subs_balcadv >= subs_balcadv_90)
label var subs_balcadv_up "subs_balcadv if >= subs_balcadv_90"
gen subs_balcadv_dn = subs_balcadv * (subs_balcadv < subs_balcadv_90)
label var subs_balcadv_dn "subs_balcadv if < subs_balcadv_90"

* regressions

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_balcadv_90 subs_volrcadv_90 subs_balcadv_up subs_balcadv_dn subs_reffpen subs_secrealx subs_fdiflw subs_herfsale  plant_lnempl plant_indcoll plant_indhigh plant_indwhittot tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv  subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv  subs_tarfoutp_balcadv_90 subs_tarfintm_balcadv_90 subs_tarfoutp_indexp_balcadv_90 subs_tarfintm_indexp_balcadv_90 subs_tarfoutp_volrcadv_90 subs_tarfintm_volrcadv_90 subs_tarfoutp_indexp_volrcadv_90 subs_tarfintm_indexp_volrcadv_90  subs_tarfoutp_notindprim subs_tarfintm_notindprim  subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite  subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_nofe)
est2vec subshire_aerrr_intract, r(F p df df_r) name(clogit_nofe)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl
summ2tex indhire `basendog' `secexog' `exoglst' `cntrlfrm' `ivlst' `intract1' `intract2' `intract2_90' `intract2_90a' `intract3' `intract3_90' `intract3_90a' `intract4' `intract5' `intract6' `intract7' `intract8' `intract9' `addlreg' if e(sample), c(mean sd N p50) name(summ_hire_intract) p(brazrloc/estmat/v4/reg/natl) replace detail

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_yrfe)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_yrfe)

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_secyrfe)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_secyrfe)

clogit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_secyrfe0)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_secyrfe0)

clogit indhire `basendog' `secexog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract2)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract2)

clogit indhire `basendog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract20)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract20)

clogit indhire `basendog' `intract1' `intract2_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract20_90)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract20_90)

clogit indhire `basendog' `intract1' `intract2_90a' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract20_90a)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract20_90a)

clogit indhire `basendog' `secexog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract3)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract3)

clogit indhire `basendog' subs_balcadv_up subs_balcadv_dn `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract3_updn)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract3_updn)

clogit indhire `basendog' `secexog' `intract1' `intract2' `intract3' subs_reffpen `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract3_reffpen)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract3_reffpen)

clogit indhire `basendog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract30)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract30)

clogit indhire `basendog' `intract1' `intract2_90' `intract3_90' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract30_90)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract30_90)

clogit indhire `basendog' `intract1' `intract2_90' `intract3_90' subs_reffpen `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract30_90_reffpen)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract30_90_reffpen)

clogit indhire `basendog' `intract1' `intract2_90a' `intract3_90a' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract30_90a)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract30_90a)

clogit indhire `basendog' `secexog' `intract4' `intract5' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract4)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract4)

clogit indhire `basendog' `intract4' `intract5' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract40)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract40)

clogit indhire `basendog' `secexog' `intract4' `intract5' `intract6' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract7)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract7)

clogit indhire `basendog' `intract4' `intract5' `intract6' `intract7' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract70)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract70)

clogit indhire `basendog' `secexog' `intract8' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract8)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract8)

clogit indhire `basendog' `intract8' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract80)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract80)

clogit indhire `basendog' `secexog' `intract8' `intract9' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract9)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract9)

clogit indhire `basendog' `intract8' `intract9' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr_intract, addto(subshire_aerrr_intract) name(clogit_intract90)
est2vec subshire_aerrr_intract, raddto(subshire_aerrr_intract) name(clogit_intract90)


// Save results

foreach type in b se e r {
  matsave subsdspl_aerrr_intract_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  matsave subshire_aerrr_intract_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }

log close
