version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/summary-stats-aerrr-natl.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local basendog "subs_tarfoutp subs_tarfintm firm_indexp"  // cut: subs_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "subs_ppieu subs_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "subs_tarfoutp_indexp subs_tarfintm_indexp"
local intract2 "subs_tarfoutp_balcadv subs_tarfintm_balcadv"
local intract3 "subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv"
local intract4 "subs_tarfoutp_notindprim subs_tarfintm_notindprim"  // if ~indprim
local intract5 "subs_tarfoutp_indyoung subs_tarfintm_indyoung"  // if potexper < 10
local intract6 "subs_tarfoutp_indwhite subs_tarfintm_indwhite"  // if indprof | indtech | indwhit
local intract7 "subs_tarfoutp_indfemal subs_tarfintm_indfemal"  // if indfemal
local intract8 "subs_tarfoutp_notindprim subs_tarfintm_notindprim firm_indexp_notindprim subs_balcadv_notindprim"
local intract9 "subs_tarfoutp_indexp_notindprim subs_tarfoutp_balcadv_notindprim subs_tarfintm_indexp_notindprim subs_tarfintm_balcadv_notindprim"
local addlreg  "subs_indprown_pis occ_indoutsrc"
local intract2_90  "subs_tarfoutp_balcadv_90 subs_tarfintm_balcadv_90"
local intract3_90  "subs_tarfoutp_indexp_balcadv_90 subs_tarfintm_indexp_balcadv_90"
local intract2_90a "subs_tarfoutp_volrcadv_90 subs_tarfintm_volrcadv_90"
local intract3_90a "subs_tarfoutp_indexp_volrcadv_90 subs_tarfintm_indexp_volrcadv_90"

* separations natl

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf indlayoff indquit
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain Balassa quintile
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge.dta", nokeep keep(balarank)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"
drop subs_ibge

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen firm_indexp_notindprim = firm_indexp * (~indprim) // if ~indprim
label var firm_indexp_notindprim "indexp * (~indprim)"
gen subs_balcadv_notindprim = subs_balcadv * (~indprim) // if ~indprim
label var subs_balcadv_notindprim "balcadv * (~indprim)"
gen subs_tarfoutp_indexp_notindprim = subs_tarfoutp * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfoutp_indexp_notindprim "tarfoutp * indexp * (~indprim)"
gen subs_tarfoutp_balcadv_notindprim = subs_tarfoutp * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfoutp_balcadv_notindprim "tarfoutp * balcadv * (~indprim)"
gen subs_tarfintm_indexp_notindprim = subs_tarfintm * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfintm_indexp_notindprim "tarfintm * indexp * (~indprim)"
gen subs_tarfintm_balcadv_notindprim = subs_tarfintm * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfintm_balcadv_notindprim "tarfintm * balcadv * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"
gen subs_tarfoutp_indfemal = subs_tarfoutp * (indfemal) // if indfemal
label var subs_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen subs_tarfintm_indfemal = subs_tarfintm * (indfemal) // if indfemal
label var subs_tarfintm_indfemal "tarfintm * (indfemal)"
gen subs_tarfoutp_balcadv_90 = subs_tarfoutp * subs_balcadv_90
label var subs_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen subs_tarfintm_balcadv_90 = subs_tarfintm * subs_balcadv_90
label var subs_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen subs_tarfoutp_indexp_balcadv_90 = subs_tarfoutp * firm_indexp * subs_balcadv_90
label var subs_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen subs_tarfintm_indexp_balcadv_90 = subs_tarfintm * firm_indexp * subs_balcadv_90
label var subs_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen subs_tarfoutp_volrcadv_90 = subs_tarfoutp * subs_volrcadv_90
label var subs_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen subs_tarfintm_volrcadv_90 = subs_tarfintm * subs_volrcadv_90
label var subs_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen subs_tarfoutp_indexp_volrcadv_90 = subs_tarfoutp * firm_indexp * subs_volrcadv_90
label var subs_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen subs_tarfintm_indexp_volrcadv_90 = subs_tarfintm * firm_indexp * subs_volrcadv_90
label var subs_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' if year>=1990, group(wid) robust iterate(1)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1990 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1992 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1994 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1997 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1998 & indsmpl

summ2tex * if indsmpl, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_aerrr_allsec) replace detail
summ2tex * if indsmpl & balarank==1, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_aerrr_balrnk1) replace detail
summ2tex * if indsmpl & balarank==3, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_aerrr_balrnk3) replace detail
summ2tex * if indsmpl & balarank==5, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_aerrr_balrnk5) replace detail
summ2tex * if indsmpl & firm_indexp, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_aerrr_indexp) replace detail

preserve
mat summ_dspl_aerrr_timevar_tbl = J(8,4,.)
mat rownames summ_dspl_aerrr_timevar_tbl = plant_lnempl:1990 plant_lnempl:1992 plant_lnempl:1994 plant_lnempl:1998 firm_lnlp:1990 firm_lnlp:1992 firm_lnlp:1994 firm_lnlp:1998
mat colnames summ_dspl_aerrr_timevar_tbl = mean:allsec sd:allsec mean:balarank5 mean:firm_indexp
foreach var in plant_lnempl firm_lnlp {
  foreach yr in 90 92 94 98 {
    qui summ `var' if year==19`yr'
    mat summ_dspl_aerrr_timevar_tbl[rownumb(summ_dspl_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_aerrr_timevar_tbl,"mean:allsec")] = `r(mean)'
    mat summ_dspl_aerrr_timevar_tbl[rownumb(summ_dspl_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_aerrr_timevar_tbl,"sd:allsec")] = `r(sd)'
    qui summ `var' if year==19`yr' & balarank==5, meanonly
    mat summ_dspl_aerrr_timevar_tbl[rownumb(summ_dspl_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_aerrr_timevar_tbl,"mean:balarank5")] = `r(mean)'
    qui summ `var' if year==19`yr' & firm_indexp, meanonly
    mat summ_dspl_aerrr_timevar_tbl[rownumb(summ_dspl_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_aerrr_timevar_tbl,"mean:firm_indexp")] = `r(mean)'
    }
  }
est2tex summ_dspl_aerrr_timevar, ready dropall path(brazrloc/estmat/v4/reg/natl) replace
restore

keep cnpj_radic year firm_indexp balarank indsmpl
bysort cnpj_radic year indsmpl: keep if _n==1
collapse (sum) firm_indexp if indsmpl, by(balarank year) fast
list

* accessions natl

local cntrlwrk "potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain Balassa quintile
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge.dta", nokeep keep(balarank)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"
drop subs_ibge

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_indfemal = subs_tarfoutp * (indfemal) // if indfemal
label var subs_tarfoutp_indfemal "tarfoutp * (indfemal)"
gen subs_tarfintm_indfemal = subs_tarfintm * (indfemal) // if indfemal
label var subs_tarfintm_indfemal "tarfintm * (indfemal)"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen firm_indexp_notindprim = firm_indexp * (~indprim) // if ~indprim
label var firm_indexp_notindprim "indexp * (~indprim)"
gen subs_balcadv_notindprim = subs_balcadv * (~indprim) // if ~indprim
label var subs_balcadv_notindprim "balcadv * (~indprim)"
gen subs_tarfoutp_indexp_notindprim = subs_tarfoutp * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfoutp_indexp_notindprim "tarfoutp * indexp * (~indprim)"
gen subs_tarfoutp_balcadv_notindprim = subs_tarfoutp * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfoutp_balcadv_notindprim "tarfoutp * balcadv * (~indprim)"
gen subs_tarfintm_indexp_notindprim = subs_tarfintm * firm_indexp * (~indprim) // if ~indprim
label var subs_tarfintm_indexp_notindprim "tarfintm * indexp * (~indprim)"
gen subs_tarfintm_balcadv_notindprim = subs_tarfintm * subs_balcadv * (~indprim) // if ~indprim
label var subs_tarfintm_balcadv_notindprim "tarfintm * balcadv * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"
gen subs_tarfoutp_balcadv_90 = subs_tarfoutp * subs_balcadv_90
label var subs_tarfoutp_balcadv_90 "tarfoutp * balcadv_90"
gen subs_tarfintm_balcadv_90 = subs_tarfintm * subs_balcadv_90
label var subs_tarfintm_balcadv_90 "tarfintm * balcadv_90"
gen subs_tarfoutp_indexp_balcadv_90 = subs_tarfoutp * firm_indexp * subs_balcadv_90
label var subs_tarfoutp_indexp_balcadv_90 "tarfoutp * indexp * balcadv_90"
gen subs_tarfintm_indexp_balcadv_90 = subs_tarfintm * firm_indexp * subs_balcadv_90
label var subs_tarfintm_indexp_balcadv_90 "tarfintm * indexp * balcadv_90"
gen subs_tarfoutp_volrcadv_90 = subs_tarfoutp * subs_volrcadv_90
label var subs_tarfoutp_volrcadv_90 "tarfoutp * volrcadv_90"
gen subs_tarfintm_volrcadv_90 = subs_tarfintm * subs_volrcadv_90
label var subs_tarfintm_volrcadv_90 "tarfintm * volrcadv_90"
gen subs_tarfoutp_indexp_volrcadv_90 = subs_tarfoutp * firm_indexp * subs_volrcadv_90
label var subs_tarfoutp_indexp_volrcadv_90 "tarfoutp * indexp * volrcadv_90"
gen subs_tarfintm_indexp_volrcadv_90 = subs_tarfintm * firm_indexp * subs_volrcadv_90
label var subs_tarfintm_indexp_volrcadv_90 "tarfintm * indexp * volrcadv_90"

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' if year>=1990, group(wid) robust iterate(1)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1990 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1992 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1994 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1997 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1998 & indsmpl

summ2tex * if indsmpl, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_aerrr_allsec) replace detail
summ2tex * if indsmpl & balarank==1, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_aerrr_balrnk1) replace detail
summ2tex * if indsmpl & balarank==3, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_aerrr_balrnk3) replace detail
summ2tex * if indsmpl & balarank==5, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_aerrr_balrnk5) replace detail
summ2tex * if indsmpl & firm_indexp, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_aerrr_indexp) replace detail

preserve
mat summ_hire_aerrr_timevar_tbl = J(8,4,.)
mat rownames summ_hire_aerrr_timevar_tbl = plant_lnempl:1990 plant_lnempl:1992 plant_lnempl:1994 plant_lnempl:1998 firm_lnlp:1990 firm_lnlp:1992 firm_lnlp:1994 firm_lnlp:1998
mat colnames summ_hire_aerrr_timevar_tbl = mean:allsec sd:allsec mean:balarank5 mean:firm_indexp
foreach var in plant_lnempl firm_lnlp {
  foreach yr in 90 92 94 98 {
    qui summ `var' if year==19`yr'
    mat summ_hire_aerrr_timevar_tbl[rownumb(summ_hire_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_aerrr_timevar_tbl,"mean:allsec")] = `r(mean)'
    mat summ_hire_aerrr_timevar_tbl[rownumb(summ_hire_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_aerrr_timevar_tbl,"sd:allsec")] = `r(sd)'
    qui summ `var' if year==19`yr' & balarank==5, meanonly
    mat summ_hire_aerrr_timevar_tbl[rownumb(summ_hire_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_aerrr_timevar_tbl,"mean:balarank5")] = `r(mean)'
    qui summ `var' if year==19`yr' & firm_indexp, meanonly
    mat summ_hire_aerrr_timevar_tbl[rownumb(summ_hire_aerrr_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_aerrr_timevar_tbl,"mean:firm_indexp")] = `r(mean)'
    }
  }
est2tex summ_hire_aerrr_timevar, ready dropall path(brazrloc/estmat/v4/reg/natl) replace
restore


log close
